@@ -27,10 +27,9 @@ import io.netty.util.ReferenceCounted;
 import org.apache.bookkeeper.client.api.LedgerEntry;
 import org.apache.bookkeeper.mledger.Entry;
 import org.apache.bookkeeper.mledger.util.AbstractCASReferenceCounted;
-import org.apache.bookkeeper.mledger.util.RangeCache;
 
 public final class EntryImpl extends AbstractCASReferenceCounted implements Entry, Comparable<EntryImpl>,
-        RangeCache.ValueWithKeyValidation<PositionImpl> {
+        ReferenceCounted {
 
     private static final Recycler<EntryImpl> RECYCLER = new Recycler<EntryImpl>() {
         @Override
@@ -206,8 +205,4 @@ public final class EntryImpl extends AbstractCASReferenceCounted implements Entr
         recyclerHandle.recycle(this);
     }
 
-    @Override
-    public boolean matchesKey(PositionImpl key) {
-        return key.compareTo(ledgerId, entryId) == 0;
-    }
 }
