@@ -50,6 +50,9 @@ public class TopicResources {
         store.registerListener(this::handleNotification);
     }
 
+    /***
+     * List persistent topics names under a namespace, the topic name contains the partition suffix.
+     */
     public CompletableFuture<List<String>> listPersistentTopicsAsync(NamespaceName ns) {
         String path = MANAGED_LEDGER_PATH + "/" + ns + "/persistent";
 
@@ -117,7 +120,7 @@ public class TopicResources {
         return store.exists(path)
                 .thenCompose(exists -> {
                     if (exists) {
-                        return store.delete(path, Optional.empty());
+                        return store.deleteRecursive(path);
                     } else {
                         return CompletableFuture.completedFuture(null);
                     }
