@@ -19,8 +19,6 @@
 package org.apache.pulsar;
 
 import static org.apache.pulsar.common.policies.data.PoliciesUtil.getBundles;
-import com.beust.jcommander.JCommander;
-import com.beust.jcommander.Parameter;
 import java.io.IOException;
 import java.util.Collections;
 import java.util.Optional;
@@ -58,6 +56,10 @@ import org.apache.pulsar.metadata.impl.MetadataStoreFactoryImpl;
 import org.apache.pulsar.metadata.impl.ZKMetadataStore;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import picocli.CommandLine;
+import picocli.CommandLine.Command;
+import picocli.CommandLine.Option;
+import picocli.CommandLine.ScopeType;
 
 /**
  * Setup the metadata for a new Pulsar cluster.
@@ -66,75 +68,76 @@ public class PulsarClusterMetadataSetup {
 
     private static final int DEFAULT_BUNDLE_NUMBER = 16;
 
+    @Command(name = "initialize-cluster-metadata", showDefaultValues = true, scope = ScopeType.INHERIT)
     private static class Arguments {
-        @Parameter(names = { "-c", "--cluster" }, description = "Cluster name", required = true)
+        @Option(names = {"-c", "--cluster"}, description = "Cluster name", required = true)
         private String cluster;
 
-        @Parameter(names = {"-bn",
+        @Option(names = {"-bn",
                 "--default-namespace-bundle-number"},
                 description = "The bundle numbers for the default namespaces(public/default), default is 16",
                 required = false)
         private int numberOfDefaultNamespaceBundles;
 
-        @Parameter(names = { "-uw",
-                "--web-service-url" }, description = "Web-service URL for new cluster", required = true)
+        @Option(names = {"-uw",
+                "--web-service-url"}, description = "Web-service URL for new cluster", required = true)
         private String clusterWebServiceUrl;
 
-        @Parameter(names = {"-tw",
+        @Option(names = {"-tw",
                 "--web-service-url-tls"},
                 description = "Web-service URL for new cluster with TLS encryption", required = false)
         private String clusterWebServiceUrlTls;
 
-        @Parameter(names = { "-ub",
-                "--broker-service-url" }, description = "Broker-service URL for new cluster", required = false)
+        @Option(names = {"-ub",
+                "--broker-service-url"}, description = "Broker-service URL for new cluster", required = false)
         private String clusterBrokerServiceUrl;
 
-        @Parameter(names = {"-tb",
+        @Option(names = {"-tb",
                 "--broker-service-url-tls"},
                 description = "Broker-service URL for new cluster with TLS encryption", required = false)
         private String clusterBrokerServiceUrlTls;
 
-        @Parameter(names = { "-zk",
-                "--zookeeper" }, description = "Local ZooKeeper quorum connection string",
+        @Option(names = {"-zk",
+                "--zookeeper"}, description = "Local ZooKeeper quorum connection string",
                 required = false,
                 hidden = true
-                )
+        )
         private String zookeeper;
 
-        @Parameter(names = { "-md",
-                "--metadata-store" }, description = "Metadata Store service url. eg: zk:my-zk:2181", required = false)
+        @Option(names = {"-md",
+                "--metadata-store"}, description = "Metadata Store service url. eg: zk:my-zk:2181", required = false)
         private String metadataStoreUrl;
 
-        @Parameter(names = {
-            "--zookeeper-session-timeout-ms"
+        @Option(names = {
+                "--zookeeper-session-timeout-ms"
         }, description = "Local zookeeper session timeout ms")
         private int zkSessionTimeoutMillis = 30000;
 
-        @Parameter(names = {"-gzk",
+        @Option(names = {"-gzk",
                 "--global-zookeeper"},
                 description = "Global ZooKeeper quorum connection string", required = false, hidden = true)
         private String globalZookeeper;
 
-        @Parameter(names = {"-cs",
+        @Option(names = {"-cs",
                 "--configuration-store"}, description = "Configuration Store connection string", hidden = true)
         private String configurationStore;
 
-        @Parameter(names = {"-cms",
+        @Option(names = {"-cms",
                 "--configuration-metadata-store"}, description = "Configuration Metadata Store connection string",
                 hidden = false)
         private String configurationMetadataStore;
 
-        @Parameter(names = {
-            "--initial-num-stream-storage-containers"
+        @Option(names = {
+                "--initial-num-stream-storage-containers"
         }, description = "Num storage containers of BookKeeper stream storage")
         private int numStreamStorageContainers = 16;
 
-        @Parameter(names = {
+        @Option(names = {
                 "--initial-num-transaction-coordinators"
         }, description = "Num transaction coordinators will assigned in cluster")
         private int numTransactionCoordinators = 16;
 
-        @Parameter(names = {
+        @Option(names = {
                 "--existing-bk-metadata-service-uri"},
                 description = "The metadata service URI of the existing BookKeeper cluster that you want to use")
         private String existingBkMetadataServiceUri;
@@ -142,26 +145,26 @@ public class PulsarClusterMetadataSetup {
         // Hide and marked as deprecated this flag because we use the new name '--existing-bk-metadata-service-uri' to
         // pass the service url. For compatibility of the command, we should keep both to avoid the exceptions.
         @Deprecated
-        @Parameter(names = {
-            "--bookkeeper-metadata-service-uri"},
-            description = "The metadata service URI of the existing BookKeeper cluster that you want to use",
-            hidden = true)
+        @Option(names = {
+                "--bookkeeper-metadata-service-uri"},
+                description = "The metadata service URI of the existing BookKeeper cluster that you want to use",
+                hidden = true)
         private String bookieMetadataServiceUri;
 
-        @Parameter(names = { "-pp",
-                "--proxy-protocol" },
+        @Option(names = {"-pp",
+                "--proxy-protocol"},
                 description = "Proxy protocol to select type of routing at proxy. Possible Values: [SNI]",
                 required = false)
         private ProxyProtocol clusterProxyProtocol;
 
-        @Parameter(names = { "-pu",
-                "--proxy-url" }, description = "Proxy-server URL to which to connect.", required = false)
+        @Option(names = {"-pu",
+                "--proxy-url"}, description = "Proxy-server URL to which to connect.", required = false)
         private String clusterProxyUrl;
 
-        @Parameter(names = { "-h", "--help" }, description = "Show this help message")
+        @Option(names = {"-h", "--help"}, usageHelp = true, description = "Show this help message")
         private boolean help = false;
 
-        @Parameter(names = {"-g", "--generate-docs"}, description = "Generate docs")
+        @Option(names = {"-g", "--generate-docs"}, description = "Generate docs")
         private boolean generateDocs = false;
     }
 
@@ -197,28 +200,27 @@ public class PulsarClusterMetadataSetup {
         System.setProperty("bookkeeper.metadata.client.drivers", PulsarMetadataClientDriver.class.getName());
 
         Arguments arguments = new Arguments();
-        JCommander jcommander = new JCommander();
+        CommandLine commander = new CommandLine(arguments);
         try {
-            jcommander.addObject(arguments);
-            jcommander.parse(args);
+            commander.parseArgs(args);
             if (arguments.help) {
-                jcommander.usage();
+                commander.usage(commander.getOut());
                 return;
             }
             if (arguments.generateDocs) {
                 CmdGenerateDocs cmd = new CmdGenerateDocs("pulsar");
-                cmd.addCommand("initialize-cluster-metadata", arguments);
+                cmd.addCommand("initialize-cluster-metadata", commander);
                 cmd.run(null);
                 return;
             }
         } catch (Exception e) {
-            jcommander.usage();
+            commander.getErr().println(e);
             throw e;
         }
 
         if (arguments.metadataStoreUrl == null && arguments.zookeeper == null) {
             System.err.println("Metadata store address argument is required (--metadata-store)");
-            jcommander.usage();
+            commander.usage(commander.getOut());
             System.exit(1);
         }
 
@@ -226,7 +228,7 @@ public class PulsarClusterMetadataSetup {
                 && arguments.globalZookeeper == null) {
             System.err.println(
                     "Configuration metadata store address argument is required (--configuration-metadata-store)");
-            jcommander.usage();
+            commander.usage(commander.getOut());
             System.exit(1);
         }
 
@@ -234,7 +236,7 @@ public class PulsarClusterMetadataSetup {
                 || arguments.globalZookeeper != null)) {
             System.err.println("Configuration metadata store argument (--configuration-metadata-store) "
                     + "supersedes the deprecated (--global-zookeeper and --configuration-store) argument");
-            jcommander.usage();
+            commander.usage(commander.getOut());
             System.exit(1);
         }
 
@@ -373,8 +375,8 @@ public class PulsarClusterMetadataSetup {
         }
     }
 
-    public static void createNamespaceIfAbsent(PulsarResources resources, NamespaceName namespaceName,
-                                               String cluster, int bundleNumber) throws IOException {
+    static void createNamespaceIfAbsent(PulsarResources resources, NamespaceName namespaceName,
+            String cluster, int bundleNumber) throws IOException {
         NamespaceResources namespaceResources = resources.getNamespaceResources();
 
         if (!namespaceResources.namespaceExists(namespaceName)) {
