@@ -36,6 +36,7 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
@@ -84,6 +85,7 @@ import org.apache.pulsar.broker.loadbalance.extensions.store.LoadDataStore;
 import org.apache.pulsar.broker.loadbalance.extensions.store.LoadDataStoreException;
 import org.apache.pulsar.broker.loadbalance.extensions.store.LoadDataStoreFactory;
 import org.apache.pulsar.broker.loadbalance.extensions.strategy.BrokerSelectionStrategy;
+import org.apache.pulsar.broker.loadbalance.extensions.strategy.BrokerSelectionStrategyFactory;
 import org.apache.pulsar.broker.loadbalance.extensions.strategy.LeastResourceUsageWithWeight;
 import org.apache.pulsar.broker.loadbalance.impl.LoadManagerShared;
 import org.apache.pulsar.broker.loadbalance.impl.SimpleResourceAllocationPolicies;
@@ -103,7 +105,7 @@ import org.apache.pulsar.metadata.api.coordination.LeaderElectionState;
 import org.slf4j.Logger;
 
 @Slf4j
-public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
+public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager, BrokerSelectionStrategyFactory {
 
     public static final String BROKER_LOAD_DATA_STORE_TOPIC = TopicName.get(
             TopicDomain.non_persistent.value(),
@@ -123,9 +125,6 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
 
     private static final String ELECTION_ROOT = "/loadbalance/extension/leader";
 
-    private static final Set<String> INTERNAL_TOPICS =
-            Set.of(BROKER_LOAD_DATA_STORE_TOPIC, TOP_BUNDLES_LOAD_DATA_STORE_TOPIC, TOPIC);
-
     private PulsarService pulsar;
 
     private ServiceConfiguration conf;
@@ -168,10 +167,10 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
 
     private TopBundleLoadDataReporter topBundleLoadDataReporter;
 
-    private volatile ScheduledFuture brokerLoadDataReportTask;
-    private volatile ScheduledFuture topBundlesLoadDataReportTask;
+    private ScheduledFuture brokerLoadDataReportTask;
+    private ScheduledFuture topBundlesLoadDataReportTask;
 
-    private volatile ScheduledFuture monitorTask;
+    private ScheduledFuture monitorTask;
     private SplitScheduler splitScheduler;
 
     private UnloadManager unloadManager;
@@ -189,7 +188,9 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
 
     // Record the ignored send msg count during unloading
     @Getter
-    private final AtomicLong ignoredSendMsgCounter = new AtomicLong();
+    private final AtomicLong ignoredSendMsgCount = new AtomicLong();
+    @Getter
+    private final AtomicLong ignoredAckCount = new AtomicLong();
 
     // record unload metrics
     private final AtomicReference<List<Metrics>> unloadMetrics = new AtomicReference<>();
@@ -198,7 +199,7 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
 
     private final ConcurrentHashMap<String, CompletableFuture<Optional<BrokerLookupData>>>
             lookupRequests = new ConcurrentHashMap<>();
-    private final CompletableFuture<Void> initWaiter = new CompletableFuture<>();
+    private final CountDownLatch initWaiter = new CountDownLatch(1);
 
     /**
      * Get all the bundles that are owned by this broker.
@@ -245,6 +246,11 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
                 }).thenApply(__ -> ownedServiceUnits);
     }
 
+    @Override
+    public BrokerSelectionStrategy createBrokerSelectionStrategy() {
+        return new LeastResourceUsageWithWeight();
+    }
+
     public enum Role {
         Leader,
         Follower
@@ -260,8 +266,7 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
         this.brokerFilterPipeline.add(new BrokerLoadManagerClassFilter());
         this.brokerFilterPipeline.add(new BrokerMaxTopicCountFilter());
         this.brokerFilterPipeline.add(new BrokerVersionFilter());
-        // TODO: Make brokerSelectionStrategy configurable.
-        this.brokerSelectionStrategy = new LeastResourceUsageWithWeight();
+        this.brokerSelectionStrategy = createBrokerSelectionStrategy();
     }
 
     public static boolean isLoadManagerExtensionEnabled(PulsarService pulsar) {
@@ -309,8 +314,7 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
     private static boolean configureSystemTopics(PulsarService pulsar) {
         try {
             if (ExtensibleLoadManagerImpl.isLoadManagerExtensionEnabled(pulsar)
-                    && (pulsar.getConfiguration().isSystemTopicEnabled())
-                    && pulsar.getConfiguration().isTopicLevelPoliciesEnabled()) {
+                    && pulsar.getConfiguration().isSystemTopicAndTopicLevelPoliciesEnabled()) {
                 Long threshold = pulsar.getAdminClient().topicPolicies().getCompactionThreshold(TOPIC);
                 if (threshold == null || COMPACTION_THRESHOLD != threshold.longValue()) {
                     pulsar.getAdminClient().topicPolicies().setCompactionThreshold(TOPIC, COMPACTION_THRESHOLD);
@@ -331,11 +335,14 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
      * Gets the assigned broker for the given topic.
      * @param pulsar PulsarService instance
      * @param topic Topic Name
-     * @return the assigned broker's BrokerLookupData instance. Empty, if not assigned by Extensible LoadManager.
+     * @return the assigned broker's BrokerLookupData instance. Empty, if not assigned by Extensible LoadManager or the
+     *         optimized bundle unload process is disabled.
      */
     public static CompletableFuture<Optional<BrokerLookupData>> getAssignedBrokerLookupData(PulsarService pulsar,
                                                                           String topic) {
-        if (ExtensibleLoadManagerImpl.isLoadManagerExtensionEnabled(pulsar)) {
+        var config = pulsar.getConfig();
+        if (ExtensibleLoadManagerImpl.isLoadManagerExtensionEnabled(pulsar)
+                && config.isLoadBalancerMultiPhaseBundleUnload()) {
             var topicName = TopicName.get(topic);
             try {
                 return pulsar.getNamespaceService().getBundleAsync(topicName)
@@ -369,30 +376,22 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
                     pulsar.getCoordinationService(), pulsar.getBrokerId(),
                     pulsar.getSafeWebServiceAddress(), ELECTION_ROOT,
                     state -> {
-                        pulsar.runWhenReadyForIncomingRequests(() -> {
-                            pulsar.getLoadManagerExecutor().execute(() -> {
-                                if (state == LeaderElectionState.Leading) {
-                                    playLeader();
-                                } else {
-                                    playFollower();
-                                }
-                            });
+                        pulsar.getLoadManagerExecutor().execute(() -> {
+                            if (state == LeaderElectionState.Leading) {
+                                playLeader();
+                            } else {
+                                playFollower();
+                            }
                         });
                     });
             this.serviceUnitStateChannel = new ServiceUnitStateChannelImpl(pulsar);
             this.brokerRegistry.start();
             this.splitManager = new SplitManager(splitCounter);
-            this.unloadManager = new UnloadManager(unloadCounter);
+            this.unloadManager = new UnloadManager(unloadCounter, pulsar.getBrokerId());
             this.serviceUnitStateChannel.listen(unloadManager);
             this.serviceUnitStateChannel.listen(splitManager);
             this.leaderElectionService.start();
-            pulsar.runWhenReadyForIncomingRequests(() -> {
-                try {
-                    this.serviceUnitStateChannel.start();
-                } catch (Exception e) {
-                    failStarting(e);
-                }
-            });
+            this.serviceUnitStateChannel.start();
             this.antiAffinityGroupPolicyHelper =
                     new AntiAffinityGroupPolicyHelper(pulsar, serviceUnitStateChannel);
             antiAffinityGroupPolicyHelper.listenFailureDomainUpdate();
@@ -424,72 +423,54 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
                     new TopBundleLoadDataReporter(pulsar, brokerRegistry.getBrokerId(), topBundlesLoadDataStore);
             this.serviceUnitStateChannel.listen(brokerLoadDataReporter);
             this.serviceUnitStateChannel.listen(topBundleLoadDataReporter);
+            var interval = conf.getLoadBalancerReportUpdateMinIntervalMillis();
+            this.brokerLoadDataReportTask = this.pulsar.getLoadManagerExecutor()
+                    .scheduleAtFixedRate(() -> {
+                                try {
+                                    brokerLoadDataReporter.reportAsync(false);
+                                    // TODO: update broker load metrics using getLocalData
+                                } catch (Throwable e) {
+                                    log.error("Failed to run the broker load manager executor job.", e);
+                                }
+                            },
+                            interval,
+                            interval, TimeUnit.MILLISECONDS);
+
+            this.topBundlesLoadDataReportTask = this.pulsar.getLoadManagerExecutor()
+                    .scheduleAtFixedRate(() -> {
+                                try {
+                                    // TODO: consider excluding the bundles that are in the process of split.
+                                    topBundleLoadDataReporter.reportAsync(false);
+                                } catch (Throwable e) {
+                                    log.error("Failed to run the top bundles load manager executor job.", e);
+                                }
+                            },
+                            interval,
+                            interval, TimeUnit.MILLISECONDS);
+
+            this.monitorTask = this.pulsar.getLoadManagerExecutor()
+                    .scheduleAtFixedRate(() -> {
+                                monitor();
+                            },
+                            MONITOR_INTERVAL_IN_MILLIS,
+                            MONITOR_INTERVAL_IN_MILLIS, TimeUnit.MILLISECONDS);
 
             this.unloadScheduler = new UnloadScheduler(
                     pulsar, pulsar.getLoadManagerExecutor(), unloadManager, context,
                     serviceUnitStateChannel, unloadCounter, unloadMetrics);
             this.splitScheduler = new SplitScheduler(
                     pulsar, serviceUnitStateChannel, splitManager, splitCounter, splitMetrics, context);
-
-            pulsar.runWhenReadyForIncomingRequests(() -> {
-                try {
-                    var interval = conf.getLoadBalancerReportUpdateMinIntervalMillis();
-
-                    this.brokerLoadDataReportTask = this.pulsar.getLoadManagerExecutor()
-                            .scheduleAtFixedRate(() -> {
-                                        try {
-                                            brokerLoadDataReporter.reportAsync(false);
-                                            // TODO: update broker load metrics using getLocalData
-                                        } catch (Throwable e) {
-                                            log.error("Failed to run the broker load manager executor job.", e);
-                                        }
-                                    },
-                                    interval,
-                                    interval, TimeUnit.MILLISECONDS);
-
-                    this.topBundlesLoadDataReportTask = this.pulsar.getLoadManagerExecutor()
-                            .scheduleAtFixedRate(() -> {
-                                        try {
-                                            // TODO: consider excluding the bundles that are in the process of split.
-                                            topBundleLoadDataReporter.reportAsync(false);
-                                        } catch (Throwable e) {
-                                            log.error("Failed to run the top bundles load manager executor job.", e);
-                                        }
-                                    },
-                                    interval,
-                                    interval, TimeUnit.MILLISECONDS);
-
-                    this.monitorTask = this.pulsar.getLoadManagerExecutor()
-                            .scheduleAtFixedRate(() -> {
-                                        monitor();
-                                    },
-                                    MONITOR_INTERVAL_IN_MILLIS,
-                                    MONITOR_INTERVAL_IN_MILLIS, TimeUnit.MILLISECONDS);
-
-                    this.splitScheduler.start();
-                    this.initWaiter.complete(null);
-                    this.started = true;
-                    log.info("Started load manager.");
-                } catch (Exception ex) {
-                    failStarting(ex);
-                }
-            });
+            this.splitScheduler.start();
+            this.initWaiter.countDown();
+            this.started = true;
+            log.info("Started load manager.");
         } catch (Exception ex) {
-            failStarting(ex);
-        }
-    }
-
-    private void failStarting(Exception ex) {
-        log.error("Failed to start the extensible load balance and close broker registry {}.",
-                this.brokerRegistry, ex);
-        if (this.brokerRegistry != null) {
-            try {
+            log.error("Failed to start the extensible load balance and close broker registry {}.",
+                    this.brokerRegistry, ex);
+            if (this.brokerRegistry != null) {
                 brokerRegistry.close();
-            } catch (PulsarServerException e) {
-                // ignore
             }
         }
-        initWaiter.completeExceptionally(ex);
     }
 
     @Override
@@ -686,10 +667,7 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
     }
 
     public CompletableFuture<Void> unloadNamespaceBundleAsync(ServiceUnitId bundle,
-                                                              Optional<String> destinationBroker,
-                                                              boolean force,
-                                                              long timeout,
-                                                              TimeUnit timeoutUnit) {
+                                                              Optional<String> destinationBroker) {
         if (NamespaceService.isSLAOrHeartbeatNamespace(bundle.getNamespaceObject().toString())) {
             log.info("Skip unloading namespace bundle: {}.", bundle);
             return CompletableFuture.completedFuture(null);
@@ -708,11 +686,11 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
                         log.warn(msg);
                         throw new IllegalArgumentException(msg);
                     }
-                    Unload unload = new Unload(sourceBroker, bundle.toString(), destinationBroker, force);
+                    Unload unload = new Unload(sourceBroker, bundle.toString(), destinationBroker, true);
                     UnloadDecision unloadDecision =
                             new UnloadDecision(unload, UnloadDecision.Label.Success, UnloadDecision.Reason.Admin);
                     return unloadAsync(unloadDecision,
-                            timeout, timeoutUnit);
+                            conf.getNamespaceBundleUnloadingTimeoutMs(), TimeUnit.MILLISECONDS);
                 });
     }
 
@@ -822,8 +800,7 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
     }
 
     public static boolean isInternalTopic(String topic) {
-        return INTERNAL_TOPICS.contains(topic)
-                || topic.startsWith(TOPIC)
+        return topic.startsWith(TOPIC)
                 || topic.startsWith(BROKER_LOAD_DATA_STORE_TOPIC)
                 || topic.startsWith(TOP_BUNDLES_LOAD_DATA_STORE_TOPIC);
     }
@@ -836,7 +813,7 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
         boolean becameFollower = false;
         while (!Thread.currentThread().isInterrupted()) {
             try {
-                initWaiter.get();
+                initWaiter.await();
                 if (!serviceUnitStateChannel.isChannelOwner()) {
                     becameFollower = true;
                     break;
@@ -886,7 +863,7 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
         boolean becameLeader = false;
         while (!Thread.currentThread().isInterrupted()) {
             try {
-                initWaiter.get();
+                initWaiter.await();
                 if (serviceUnitStateChannel.isChannelOwner()) {
                     becameLeader = true;
                     break;
@@ -939,16 +916,24 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
         }
 
         metricsCollection.addAll(this.assignCounter.toMetrics(pulsar.getAdvertisedAddress()));
-
         metricsCollection.addAll(this.serviceUnitStateChannel.getMetrics());
+        metricsCollection.addAll(getIgnoredCommandMetrics(pulsar.getAdvertisedAddress()));
 
         return metricsCollection;
     }
 
+    private List<Metrics> getIgnoredCommandMetrics(String advertisedBrokerAddress) {
+        var dimensions = Map.of("broker", advertisedBrokerAddress, "metric", "bundleUnloading");
+        var metric = Metrics.create(dimensions);
+        metric.put("brk_lb_ignored_ack_total", ignoredAckCount.get());
+        metric.put("brk_lb_ignored_send_total", ignoredSendMsgCount.get());
+        return List.of(metric);
+    }
+
     @VisibleForTesting
     protected void monitor() {
         try {
-            initWaiter.get();
+            initWaiter.await();
 
             // Monitor role
             // Periodically check the role in case ZK watcher fails.
@@ -980,26 +965,5 @@ public class ExtensibleLoadManagerImpl implements ExtensibleLoadManager {
         serviceUnitStateChannel.cleanOwnerships();
         leaderElectionService.close();
         brokerRegistry.unregister();
-        // Close the internal topics (if owned any) after giving up the possible leader role,
-        // so that the subsequent lookups could hit the next leader.
-        closeInternalTopics();
-    }
-
-    private void closeInternalTopics() {
-        List<CompletableFuture<Void>> futures = new ArrayList<>();
-        for (String name : INTERNAL_TOPICS) {
-            futures.add(pulsar.getBrokerService().getTopicIfExists(name)
-                    .thenAccept(topicOptional -> topicOptional.ifPresent(topic -> topic.close(true)))
-                    .exceptionally(__ -> {
-                        log.warn("Failed to close internal topic:{}", name);
-                        return null;
-                    }));
-        }
-        try {
-            FutureUtil.waitForAll(futures)
-                    .get(pulsar.getConfiguration().getNamespaceBundleUnloadingTimeoutMs(), TimeUnit.MILLISECONDS);
-        } catch (Throwable e) {
-            log.warn("Failed to wait for closing internal topics", e);
-        }
     }
 }
