@@ -76,8 +76,8 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
      */
     private final LinkedMap<TxnID, PositionImpl> ongoingTxns = new LinkedMap<>();
 
-    // when change max read position, the count will +1. Take snapshot will reset the count.
-    private final AtomicLong changeMaxReadPositionCount = new AtomicLong();
+    // when add abort or change max read position, the count will +1. Take snapshot will set 0 into it.
+    private final AtomicLong changeMaxReadPositionAndAddAbortTimes = new AtomicLong();
 
     private final LongAdder txnCommittedCounter = new LongAdder();
 
@@ -103,7 +103,6 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
     private final AbortedTxnProcessor snapshotAbortedTxnProcessor;
 
     private final AbortedTxnProcessor.SnapshotType snapshotType;
-    private final MaxReadPositionCallBack maxReadPositionCallBack;
 
     public TopicTransactionBuffer(PersistentTopic topic) {
         super(State.None);
@@ -121,7 +120,6 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
             snapshotAbortedTxnProcessor = new SingleSnapshotAbortedTxnProcessorImpl(topic);
             snapshotType = AbortedTxnProcessor.SnapshotType.Single;
         }
-        this.maxReadPositionCallBack = topic.getMaxReadPositionCallBack();
         this.recover();
     }
 
@@ -177,7 +175,7 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
                                     if (Markers.isTxnAbortMarker(msgMetadata)) {
                                         snapshotAbortedTxnProcessor.putAbortedTxnAndPosition(txnID, position);
                                     }
-                                    removeTxnAndUpdateMaxReadPosition(txnID);
+                                    updateMaxReadPosition(txnID);
                                 } else {
                                     handleTransactionMessage(txnID, position);
                                 }
@@ -292,16 +290,10 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
             ongoingTxns.put(txnId, (PositionImpl) position);
             PositionImpl firstPosition = ongoingTxns.get(ongoingTxns.firstKey());
             // max read position is less than first ongoing transaction message position
-            updateMaxReadPosition(((ManagedLedgerImpl) topic.getManagedLedger()).getPreviousPosition(firstPosition),
-                    false);
+            maxReadPosition = ((ManagedLedgerImpl) topic.getManagedLedger()).getPreviousPosition(firstPosition);
         }
     }
 
-    // ThreadSafe
-    private void updateLastDispatchablePosition(Position position) {
-        topic.updateLastDispatchablePosition(position);
-    }
-
     @Override
     public CompletableFuture<TransactionBufferReader> openTransactionBufferReader(TxnID txnID, long startSequenceId) {
         return null;
@@ -322,7 +314,7 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
                     @Override
                     public void addComplete(Position position, ByteBuf entryData, Object ctx) {
                         synchronized (TopicTransactionBuffer.this) {
-                            removeTxnAndUpdateMaxReadPosition(txnID);
+                            updateMaxReadPosition(txnID);
                             handleLowWaterMark(txnID, lowWaterMark);
                             snapshotAbortedTxnProcessor.trimExpiredAbortedTxns();
                             takeSnapshotByChangeTimes();
@@ -369,7 +361,7 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
                     public void addComplete(Position position, ByteBuf entryData, Object ctx) {
                         synchronized (TopicTransactionBuffer.this) {
                             snapshotAbortedTxnProcessor.putAbortedTxnAndPosition(txnID, (PositionImpl) position);
-                            removeTxnAndUpdateMaxReadPosition(txnID);
+                            updateMaxReadPosition(txnID);
                             snapshotAbortedTxnProcessor.trimExpiredAbortedTxns();
                             takeSnapshotByChangeTimes();
                             txnAbortedCounter.increment();
@@ -437,56 +429,32 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
     }
 
     private void takeSnapshotByChangeTimes() {
-        if (changeMaxReadPositionCount.get() >= takeSnapshotIntervalNumber) {
-            this.changeMaxReadPositionCount.set(0);
+        if (changeMaxReadPositionAndAddAbortTimes.get() >= takeSnapshotIntervalNumber) {
+            this.changeMaxReadPositionAndAddAbortTimes.set(0);
             this.snapshotAbortedTxnProcessor.takeAbortedTxnsSnapshot(this.maxReadPosition);
         }
     }
 
     private void takeSnapshotByTimeout() {
-        if (changeMaxReadPositionCount.get() > 0) {
-            this.changeMaxReadPositionCount.set(0);
+        if (changeMaxReadPositionAndAddAbortTimes.get() > 0) {
+            this.changeMaxReadPositionAndAddAbortTimes.set(0);
             this.snapshotAbortedTxnProcessor.takeAbortedTxnsSnapshot(this.maxReadPosition);
         }
         this.timer.newTimeout(TopicTransactionBuffer.this,
                 takeSnapshotIntervalTime, TimeUnit.MILLISECONDS);
     }
 
-    /**
-     * remove the specified transaction from ongoing transaction list and update the max read position.
-     * @param txnID
-     */
-    void removeTxnAndUpdateMaxReadPosition(TxnID txnID) {
+    void updateMaxReadPosition(TxnID txnID) {
+        PositionImpl preMaxReadPosition = this.maxReadPosition;
         ongoingTxns.remove(txnID);
         if (!ongoingTxns.isEmpty()) {
             PositionImpl position = ongoingTxns.get(ongoingTxns.firstKey());
-            updateMaxReadPosition(((ManagedLedgerImpl) topic.getManagedLedger()).getPreviousPosition(position), false);
+            maxReadPosition = ((ManagedLedgerImpl) topic.getManagedLedger()).getPreviousPosition(position);
         } else {
-            updateMaxReadPosition((PositionImpl) topic.getManagedLedger().getLastConfirmedEntry(), false);
+            maxReadPosition = (PositionImpl) topic.getManagedLedger().getLastConfirmedEntry();
         }
-        // Update the last dispatchable position to null if there is a TXN finished.
-        updateLastDispatchablePosition(null);
-    }
-
-    /**
-     * update the max read position. if the new position is greater than the current max read position,
-     * we will trigger the callback, unless the disableCallback is true.
-     * Currently, we only use the callback to update the lastMaxReadPositionMovedForwardTimestamp.
-     * For non-transactional production, some marker messages will be sent to the topic, in which case we don't need
-     * to trigger the callback.
-     * @param newPosition new max read position to update.
-     * @param disableCallback whether disable the callback.
-     */
-    void updateMaxReadPosition(PositionImpl newPosition, boolean disableCallback) {
-        PositionImpl preMaxReadPosition = this.maxReadPosition;
-        this.maxReadPosition = newPosition;
-        if (preMaxReadPosition.compareTo(this.maxReadPosition) < 0) {
-            if (!checkIfNoSnapshot()) {
-                this.changeMaxReadPositionCount.getAndIncrement();
-            }
-            if (!disableCallback) {
-                maxReadPositionCallBack.maxReadPositionMovedForward(preMaxReadPosition, this.maxReadPosition);
-            }
+        if (preMaxReadPosition.compareTo(this.maxReadPosition) != 0) {
+            this.changeMaxReadPositionAndAddAbortTimes.getAndIncrement();
         }
     }
 
@@ -511,29 +479,20 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
         return snapshotAbortedTxnProcessor.checkAbortedTransaction(txnID);
     }
 
-    /**
-     * Sync max read position for normal publish.
-     * @param position {@link PositionImpl} the position to sync.
-     * @param isMarkerMessage whether the message is marker message, in such case, we
-     *                       don't need to trigger the callback to update lastMaxReadPositionMovedForwardTimestamp.
-     */
     @Override
-    public void syncMaxReadPositionForNormalPublish(PositionImpl position, boolean isMarkerMessage) {
+    public void syncMaxReadPositionForNormalPublish(PositionImpl position) {
         // when ongoing transaction is empty, proved that lastAddConfirm is can read max position, because callback
         // thread is the same tread, in this time the lastAddConfirm don't content transaction message.
         synchronized (TopicTransactionBuffer.this) {
             if (checkIfNoSnapshot()) {
-                updateMaxReadPosition(position, isMarkerMessage);
+                this.maxReadPosition = position;
             } else if (checkIfReady()) {
                 if (ongoingTxns.isEmpty()) {
-                    updateMaxReadPosition(position, isMarkerMessage);
+                    maxReadPosition = position;
+                    changeMaxReadPositionAndAddAbortTimes.incrementAndGet();
                 }
             }
         }
-        // If the message is a normal message, update the last dispatchable position.
-        if (!isMarkerMessage) {
-            updateLastDispatchablePosition(position);
-        }
     }
 
     @Override
@@ -715,18 +674,6 @@ public class TopicTransactionBuffer extends TopicTransactionBufferState implemen
         }
     }
 
-    /**
-     * A functional interface to handle the max read position move forward.
-     */
-    public interface MaxReadPositionCallBack {
-        /**
-         * callback method when max read position move forward.
-         * @param oldPosition the old max read position.
-         * @param newPosition the new max read position.
-         */
-        void maxReadPositionMovedForward(PositionImpl oldPosition, PositionImpl newPosition);
-    }
-
     static class FillEntryQueueCallback implements AsyncCallbacks.ReadEntriesCallback {
 
         private final AtomicLong outstandingReadsRequests = new AtomicLong(0);
