@@ -65,14 +65,7 @@ public abstract class ExtensibleLoadManagerImplBaseTest extends MockedPulsarServ
         this.defaultTestNamespace = defaultTestNamespace;
     }
 
-    @Override
-    protected void doInitConf() throws Exception {
-        super.doInitConf();
-        updateConfig(conf);
-    }
-
-
-    protected ServiceConfiguration updateConfig(ServiceConfiguration conf) {
+    protected ServiceConfiguration initConfig(ServiceConfiguration conf) {
         conf.setForceDeleteNamespaceAllowed(true);
         conf.setLoadManagerClassName(ExtensibleLoadManagerImpl.class.getName());
         conf.setLoadBalancerLoadSheddingStrategy(TransferShedder.class.getName());
@@ -86,9 +79,10 @@ public abstract class ExtensibleLoadManagerImplBaseTest extends MockedPulsarServ
     @Override
     @BeforeClass(alwaysRun = true)
     protected void setup() throws Exception {
+        initConfig(conf);
         super.internalSetup(conf);
         pulsar1 = pulsar;
-        var conf2 = updateConfig(getDefaultConf());
+        var conf2 = initConfig(getDefaultConf());
         additionalPulsarTestContext = createAdditionalPulsarTestContext(conf2);
         pulsar2 = additionalPulsarTestContext.getPulsarService();
 
@@ -129,6 +123,8 @@ public abstract class ExtensibleLoadManagerImplBaseTest extends MockedPulsarServ
         admin.namespaces().unload(defaultTestNamespace);
         reset(primaryLoadManager, secondaryLoadManager);
         FieldUtils.writeDeclaredField(pulsarClient, "lookup", lookupService, true);
+        pulsar1.getConfig().setLoadBalancerMultiPhaseBundleUnload(true);
+        pulsar2.getConfig().setLoadBalancerMultiPhaseBundleUnload(true);
     }
 
     protected void setPrimaryLoadManager() throws IllegalAccessException {
@@ -151,7 +147,7 @@ public abstract class ExtensibleLoadManagerImplBaseTest extends MockedPulsarServ
                 FieldUtils.readField(secondaryLoadManager, "serviceUnitStateChannel", true);
     }
 
-    protected static CompletableFuture<NamespaceBundle> getBundleAsync(PulsarService pulsar, TopicName topic) {
+    protected CompletableFuture<NamespaceBundle> getBundleAsync(PulsarService pulsar, TopicName topic) {
         return pulsar.getNamespaceService().getBundleAsync(topic);
     }
 
