@@ -74,6 +74,7 @@ import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Semaphore;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
@@ -110,7 +111,6 @@ import org.apache.pulsar.broker.namespace.NamespaceBundleSplitListener;
 import org.apache.pulsar.broker.namespace.NamespaceEphemeralData;
 import org.apache.pulsar.broker.namespace.NamespaceService;
 import org.apache.pulsar.broker.service.BrokerServiceException;
-import org.apache.pulsar.client.admin.PulsarAdmin;
 import org.apache.pulsar.client.admin.PulsarAdminException;
 import org.apache.pulsar.client.api.Consumer;
 import org.apache.pulsar.client.api.Message;
@@ -144,7 +144,7 @@ import org.testng.annotations.Test;
  * Unit test for {@link ExtensibleLoadManagerImpl}.
  */
 @Slf4j
-@Test(groups = "broker")
+@Test(groups = "flaky")
 @SuppressWarnings("unchecked")
 public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBaseTest {
 
@@ -434,19 +434,6 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
     @Test(timeOut = 30_000, dataProvider = "isPersistentTopicSubscriptionTypeTest")
     public void testTransferClientReconnectionWithoutLookup(TopicDomain topicDomain, SubscriptionType subscriptionType)
             throws Exception {
-        testTransferClientReconnectionWithoutLookup(topicDomain, subscriptionType, defaultTestNamespace, admin,
-                lookupUrl.toString(), pulsar1, pulsar2, primaryLoadManager, secondaryLoadManager);
-    }
-
-    @Test(enabled = false)
-    public static void testTransferClientReconnectionWithoutLookup(TopicDomain topicDomain,
-                                                                   SubscriptionType subscriptionType,
-                                                                   String defaultTestNamespace,
-                                                                   PulsarAdmin admin, String brokerServiceUrl,
-                                                                   PulsarService pulsar1, PulsarService pulsar2,
-                                                                   ExtensibleLoadManager primaryLoadManager,
-                                                                   ExtensibleLoadManager secondaryLoadManager)
-            throws Exception {
         var id = String.format("test-tx-client-reconnect-%s-%s", subscriptionType, UUID.randomUUID());
         var topic = String.format("%s://%s/%s", topicDomain.toString(), defaultTestNamespace, id);
         var topicName = TopicName.get(topic);
@@ -456,8 +443,7 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
         var consumers = new ArrayList<Consumer<String>>();
         try {
             var lookups = new ArrayList<LookupService>();
-            var pulsarClient = pulsarClient(brokerServiceUrl, 0);
-            clients.add(pulsarClient);
+
             @Cleanup
             var producer = pulsarClient.newProducer(Schema.STRING).topic(topic).create();
             lookups.add(spyLookupService(pulsarClient));
@@ -465,7 +451,7 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
             var consumerCount = subscriptionType == SubscriptionType.Exclusive ? 1 : 3;
 
             for (int i = 0; i < consumerCount; i++) {
-                var client = pulsarClient(brokerServiceUrl, 0);
+                var client = newPulsarClient(lookupUrl.toString(), 0);
                 clients.add(client);
                 var consumer = client.newConsumer(Schema.STRING).
                         subscriptionName(id).
@@ -492,7 +478,7 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
                 dstBrokerUrl = pulsar1.getBrokerId();
                 dstBrokerServiceUrl = pulsar1.getBrokerServiceUrl();
             }
-            checkOwnershipState(broker, bundle, primaryLoadManager, secondaryLoadManager, pulsar1);
+            checkOwnershipState(broker, bundle);
 
             var messageCountBeforeUnloading = 100;
             var messageCountAfterUnloading = 100;
@@ -586,17 +572,6 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
     @Test(timeOut = 30 * 1000, dataProvider = "isPersistentTopicSubscriptionTypeTest")
     public void testUnloadClientReconnectionWithLookup(TopicDomain topicDomain,
                                                        SubscriptionType subscriptionType) throws Exception {
-        testUnloadClientReconnectionWithLookup(topicDomain, subscriptionType, defaultTestNamespace, admin,
-                lookupUrl.toString(), pulsar1);
-    }
-
-    @Test(enabled = false)
-    public static void testUnloadClientReconnectionWithLookup(TopicDomain topicDomain,
-                                                              SubscriptionType subscriptionType,
-                                                              String defaultTestNamespace,
-                                                              PulsarAdmin admin,
-                                                              String brokerServiceUrl,
-                                                              PulsarService pulsar1) throws Exception {
         var id = String.format("test-unload-%s-client-reconnect-%s-%s",
                 topicDomain, subscriptionType, UUID.randomUUID());
         var topic = String.format("%s://%s/%s", topicDomain, defaultTestNamespace, id);
@@ -605,7 +580,6 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
         var consumers = new ArrayList<Consumer<String>>();
         try {
             @Cleanup
-            var pulsarClient = pulsarClient(brokerServiceUrl, 0);
             var producer = pulsarClient.newProducer(Schema.STRING).topic(topic).create();
 
             var consumerCount = subscriptionType == SubscriptionType.Exclusive ? 1 : 3;
@@ -670,16 +644,88 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
         }
     }
 
-    private static LookupService spyLookupService(PulsarClient client) throws IllegalAccessException {
+    @DataProvider(name = "isPersistentTopicTest")
+    public Object[][] isPersistentTopicTest() {
+        return new Object[][]{{TopicDomain.persistent}, {TopicDomain.non_persistent}};
+    }
+
+    @Test(timeOut = 30 * 1000, dataProvider = "isPersistentTopicTest")
+    public void testOptimizeUnloadDisable(TopicDomain topicDomain) throws Exception {
+        var id = String.format("test-optimize-unload-disable-%s-%s", topicDomain, UUID.randomUUID());
+        var topic = String.format("%s://%s/%s", topicDomain, defaultTestNamespace, id);
+        var topicName = TopicName.get(topic);
+
+        pulsar1.getConfig().setLoadBalancerMultiPhaseBundleUnload(false);
+        pulsar2.getConfig().setLoadBalancerMultiPhaseBundleUnload(false);
+
+        @Cleanup
+        var producer = pulsarClient.newProducer(Schema.STRING).topic(topic).create();
+
+        @Cleanup
+        var consumer = pulsarClient.newConsumer(Schema.STRING).subscriptionName(id).topic(topic).subscribe();
+
+        Awaitility.await().until(() -> producer.isConnected() && consumer.isConnected());
+
+        var lookup = spyLookupService(pulsarClient);
+
+        final CountDownLatch cdl = new CountDownLatch(3);
+
+        NamespaceBundle bundle = getBundleAsync(pulsar1, TopicName.get(topic)).get();
+        var srcBrokerServiceUrl = admin.lookups().lookupTopic(topic);
+        var dstBroker = srcBrokerServiceUrl.equals(pulsar1.getBrokerServiceUrl()) ? pulsar2 : pulsar1;
+
+        CompletableFuture<Void> unloadNamespaceBundle = CompletableFuture.runAsync(() -> {
+            try {
+                cdl.await();
+                admin.namespaces().unloadNamespaceBundle(defaultTestNamespace, bundle.getBundleRange(),
+                        dstBroker.getBrokerId());
+            } catch (InterruptedException | PulsarAdminException e) {
+                fail();
+            }
+        });
+
+        MutableInt sendCount = new MutableInt();
+        Awaitility.await().atMost(20, TimeUnit.SECONDS).ignoreExceptions().until(() -> {
+            var message = String.format("message-%d", sendCount.getValue());
+
+            AtomicBoolean messageSent = new AtomicBoolean(false);
+            while (true) {
+                var recvFuture = consumer.receiveAsync().orTimeout(1000, TimeUnit.MILLISECONDS);
+                if (!messageSent.get()) {
+                    producer.sendAsync(message).thenAccept(messageId -> {
+                        if (messageId != null) {
+                            messageSent.set(true);
+                        }
+                    }).get(1000, TimeUnit.MILLISECONDS);
+                }
+
+                if (topicDomain == TopicDomain.non_persistent) {
+                    // No need to wait for message receipt, we're only trying to stress the consumer lookup pathway.
+                    break;
+                }
+                var msg = recvFuture.get();
+                if (Objects.equals(msg.getValue(), message)) {
+                    break;
+                }
+            }
+
+            cdl.countDown();
+            return sendCount.incrementAndGet() == 10;
+        });
+
+        assertTrue(producer.isConnected());
+        assertTrue(consumer.isConnected());
+        assertTrue(unloadNamespaceBundle.isDone());
+        verify(lookup, times(2)).getBroker(topicName);
+    }
+
+    private LookupService spyLookupService(PulsarClient client) throws IllegalAccessException {
         LookupService svc = (LookupService) FieldUtils.readDeclaredField(client, "lookup", true);
         var lookup = spy(svc);
         FieldUtils.writeDeclaredField(client, "lookup", lookup, true);
         return lookup;
     }
-
-    protected static void checkOwnershipState(String broker, NamespaceBundle bundle,
-                                              ExtensibleLoadManager primaryLoadManager,
-                                              ExtensibleLoadManager secondaryLoadManager, PulsarService pulsar1)
+    private void checkOwnershipState(String broker, NamespaceBundle bundle)
             throws ExecutionException, InterruptedException {
         var targetLoadManager = secondaryLoadManager;
         var otherLoadManager = primaryLoadManager;
@@ -691,15 +737,9 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
         assertFalse(otherLoadManager.checkOwnershipAsync(Optional.empty(), bundle).get());
     }
 
-    protected void checkOwnershipState(String broker, NamespaceBundle bundle)
-            throws ExecutionException, InterruptedException {
-        checkOwnershipState(broker, bundle, primaryLoadManager, secondaryLoadManager, pulsar1);
-    }
-
     @Test(timeOut = 30 * 1000)
     public void testSplitBundleAdminAPI() throws Exception {
-        final String namespace = "public/testSplitBundleAdminAPI";
-        admin.namespaces().createNamespace(namespace, 1);
+        String namespace = defaultTestNamespace;
         Pair<TopicName, NamespaceBundle> topicAndBundle = getBundleIsNotOwnByChangeEventTopic("test-split");
         TopicName topicName = topicAndBundle.getLeft();
         admin.topics().createPartitionedTopic(topicName.toString(), 10);
@@ -753,30 +793,6 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
         } catch (PulsarAdminException ex) {
             assertTrue(ex.getMessage().contains("Invalid bundle range"));
         }
-
-
-        // delete and retry
-        Awaitility.await()
-                .atMost(5, TimeUnit.SECONDS)
-                .untilAsserted(() -> {
-                    admin.namespaces().deleteNamespace(namespace);
-                });
-        admin.namespaces().createNamespace(namespace, 1);
-        admin.namespaces().splitNamespaceBundle(namespace, firstBundle, true, null);
-
-        Awaitility.await()
-                .atMost(5, TimeUnit.SECONDS)
-                .untilAsserted(() -> {
-                    BundlesData bundlesData = admin.namespaces().getBundles(namespace);
-                    assertEquals(bundlesData.getNumBundles(), numBundles + 1);
-                    String lowBundle = String.format("0x%08x", bundleRanges.get(0));
-                    String midBundle = String.format("0x%08x", mid);
-                    String highBundle = String.format("0x%08x", bundleRanges.get(1));
-                    assertTrue(bundlesData.getBoundaries().contains(lowBundle));
-                    assertTrue(bundlesData.getBoundaries().contains(midBundle));
-                    assertTrue(bundlesData.getBoundaries().contains(highBundle));
-                    assertEquals(splitCount.get(), 2);
-                });
     }
 
     @Test(timeOut = 30 * 1000)
@@ -1361,6 +1377,12 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
             FieldUtils.writeDeclaredField(channel1, "handlerCounters", handlerCounters, true);
         }
 
+        primaryLoadManager.getIgnoredSendMsgCount().incrementAndGet();
+        primaryLoadManager.getIgnoredSendMsgCount().incrementAndGet();
+        primaryLoadManager.getIgnoredAckCount().incrementAndGet();
+        primaryLoadManager.getIgnoredAckCount().incrementAndGet();
+        primaryLoadManager.getIgnoredAckCount().incrementAndGet();
+
         var expected = Set.of(
                 """
                         dimensions=[{broker=localhost, metric=loadBalancing}], metrics=[{brk_lb_bandwidth_in_usage=3.0, brk_lb_bandwidth_out_usage=4.0, brk_lb_cpu_usage=1.0, brk_lb_directMemory_usage=2.0, brk_lb_memory_usage=400.0}]
@@ -1431,8 +1453,9 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
                         dimensions=[{broker=localhost, metric=sunitStateChn, result=Schedule}], metrics=[{brk_sunit_state_chn_inactive_broker_cleanup_ops_total=5}]
                         dimensions=[{broker=localhost, metric=sunitStateChn, result=Success}], metrics=[{brk_sunit_state_chn_inactive_broker_cleanup_ops_total=1}]
                         dimensions=[{broker=localhost, metric=sunitStateChn}], metrics=[{brk_sunit_state_chn_orphan_su_cleanup_ops_total=3, brk_sunit_state_chn_owned_su_total=10, brk_sunit_state_chn_su_tombstone_cleanup_ops_total=2}]
+                        dimensions=[{broker=localhost, metric=bundleUnloading}], metrics=[{brk_lb_ignored_ack_total=3, brk_lb_ignored_send_total=2}]
                         """.split("\n"));
-        var actual = primaryLoadManager.getMetrics().stream().map(m -> m.toString()).collect(Collectors.toSet());
+        var actual = primaryLoadManager.getMetrics().stream().map(Metrics::toString).collect(Collectors.toSet());
         assertEquals(actual, expected);
     }
 
@@ -1633,11 +1656,7 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
         NamespaceEphemeralData namespaceEphemeralData = primaryLoadManager.tryAcquiringOwnership(bundle).get();
         assertTrue(Set.of(pulsar1.getBrokerServiceUrl(), pulsar2.getBrokerServiceUrl())
                 .contains(namespaceEphemeralData.getNativeUrl()));
-        Awaitility.await()
-                .atMost(5, TimeUnit.SECONDS)
-                .untilAsserted(() -> {
-                    admin.namespaces().deleteNamespace(namespace, true);
-                });
+        admin.namespaces().deleteNamespace(namespace);
     }
 
     @Test(timeOut = 30 * 1000)
@@ -1695,11 +1714,4 @@ public class ExtensibleLoadManagerImplTest extends ExtensibleLoadManagerImplBase
 
     }
 
-    protected static PulsarClient pulsarClient(String url, int intervalInSecs) throws PulsarClientException {
-        return
-                PulsarClient.builder()
-                        .serviceUrl(url)
-                        .statsInterval(intervalInSecs, TimeUnit.SECONDS).build();
-    }
-
 }
