@@ -110,7 +110,6 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
     private ServiceUnitStateChannel channel2;
     private String brokerId1;
     private String brokerId2;
-    private String brokerId3;
     private String bundle;
     private String bundle1;
     private String bundle2;
@@ -162,7 +161,6 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
                 FieldUtils.readDeclaredField(channel1, "brokerId", true);
         brokerId2 = (String)
                 FieldUtils.readDeclaredField(channel2, "brokerId", true);
-        brokerId3 = "broker-3";
 
         bundle = "public/default/0x00000000_0xffffffff";
         bundle1 = "public/default/0x00000000_0xfffffff0";
@@ -578,11 +576,11 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
                 childBundle1Range, Optional.empty(), childBundle2Range, Optional.empty()));
         channel1.publishSplitEventAsync(split);
 
-        waitUntilState(channel1, bundle, Init);
-        waitUntilState(channel2, bundle, Init);
+        waitUntilState(channel1, bundle, Deleted);
+        waitUntilState(channel2, bundle, Deleted);
 
-        validateHandlerCounters(channel1, 1, 0, 3, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0);
-        validateHandlerCounters(channel2, 1, 0, 3, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0);
+        validateHandlerCounters(channel1, 1, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0);
+        validateHandlerCounters(channel2, 1, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0);
         validateEventCounters(channel1, 1, 0, 1, 0, 0, 0);
         validateEventCounters(channel2, 0, 0, 0, 0, 0, 0);
         // Verify the retry count
@@ -622,7 +620,7 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
         var leader = channel1.isChannelOwnerAsync().get() ? channel1 : channel2;
         validateMonitorCounters(leader,
                 0,
-                0,
+                1,
                 0,
                 0,
                 0,
@@ -1237,17 +1235,16 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
 
 
         var leader = channel1.isChannelOwnerAsync().get() ? channel1 : channel2;
-        doReturn(CompletableFuture.completedFuture(Optional.of(brokerId1)))
-                .when(loadManager).selectAsync(any(), any(), any());
-        waitUntilStateWithMonitor(leader, bundle, Init);
-        waitUntilStateWithMonitor(channel1, bundle, Init);
-        waitUntilStateWithMonitor(channel2, bundle, Init);
+
+        waitUntilStateWithMonitor(leader, bundle, Deleted);
+        waitUntilStateWithMonitor(channel1, bundle, Deleted);
+        waitUntilStateWithMonitor(channel2, bundle, Deleted);
 
         var ownerAddr1 = channel1.getOwnerAsync(bundle);
         var ownerAddr2 = channel2.getOwnerAsync(bundle);
 
-        assertTrue(ownerAddr1.get().isEmpty());
-        assertTrue(ownerAddr2.get().isEmpty());
+        assertTrue(ownerAddr1.isCompletedExceptionally());
+        assertTrue(ownerAddr2.isCompletedExceptionally());
 
 
         FieldUtils.writeDeclaredField(channel1,
@@ -1429,19 +1426,15 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
                     assertEquals(3, count.get());
                 });
         var leader = channel1.isChannelOwnerAsync().get() ? channel1 : channel2;
-        doReturn(CompletableFuture.completedFuture(Optional.of(brokerId1)))
-                .when(loadManager).selectAsync(any(), any(), any());
         ((ServiceUnitStateChannelImpl) leader)
                 .monitorOwnerships(List.of(brokerId1, brokerId2));
-
-        waitUntilState(leader, bundle3, Init);
-        waitUntilState(channel1, bundle3, Init);
-        waitUntilState(channel2, bundle3, Init);
+        waitUntilState(leader, bundle3, Deleted);
+        waitUntilState(channel1, bundle3, Deleted);
+        waitUntilState(channel2, bundle3, Deleted);
 
 
-
-        validateHandlerCounters(channel1, 1, 0, 3, 0, 0, 0, 2, 1, 0, 0, 1, 0, 1, 0);
-        validateHandlerCounters(channel2, 1, 0, 3, 0, 0, 0, 2, 0, 0, 0, 1, 0, 1, 0);
+        validateHandlerCounters(channel1, 1, 0, 3, 0, 0, 0, 2, 1, 0, 0, 0, 0, 1, 0);
+        validateHandlerCounters(channel2, 1, 0, 3, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0);
         validateEventCounters(channel1, 1, 0, 1, 0, 0, 0);
         validateEventCounters(channel2, 0, 0, 0, 0, 0, 0);
 
@@ -1471,7 +1464,7 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
 
         validateMonitorCounters(leader,
                 0,
-                0,
+                1,
                 1,
                 0,
                 0,
@@ -1549,7 +1542,7 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
         waitUntilNewOwner(channel2, ownedBundle, brokerId2);
         assertEquals(Optional.empty(), channel2.getOwnerAsync(freeBundle).get());
         assertTrue(channel2.getOwnerAsync(deletedBundle).isCompletedExceptionally());
-        assertTrue(channel2.getOwnerAsync(splittingBundle).get().isEmpty());
+        assertTrue(channel2.getOwnerAsync(splittingBundle).isCompletedExceptionally());
 
         // clean-up
         FieldUtils.writeDeclaredField(leaderChannel, "maxCleanupDelayTimeInSecs", 3 * 60, true);
@@ -1574,40 +1567,26 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
         String broker = brokerId1;
 
         // test override states
-        String releasingBundle1 = "public/releasing1/0xfffffff0_0xffffffff";
-        String releasingBundle2 = "public/releasing2/0xfffffff0_0xffffffff";
+        String releasingBundle = "public/releasing/0xfffffff0_0xffffffff";
         String splittingBundle = bundle;
-        String assigningBundle1 = "public/assigning1/0xfffffff0_0xffffffff";
-        String assigningBundle2 = "public/assigning2/0xfffffff0_0xffffffff";
+        String assigningBundle = "public/assigning/0xfffffff0_0xffffffff";
         String freeBundle = "public/free/0xfffffff0_0xffffffff";
         String deletedBundle = "public/deleted/0xfffffff0_0xffffffff";
-        String ownedBundle1 = "public/owned1/0xfffffff0_0xffffffff";
-        String ownedBundle2 = "public/owned2SourceBundle/0xfffffff0_0xffffffff";
-        String ownedBundle3 = "public/owned3/0xfffffff0_0xffffffff";
-        String inactiveBroker = "broker-inactive-1";
-        overrideTableViews(releasingBundle1,
-                new ServiceUnitStateData(Releasing, broker, brokerId2, 1));
-        overrideTableViews(releasingBundle2,
-                new ServiceUnitStateData(Releasing, brokerId2, brokerId3, 1));
+        String ownedBundle = "public/owned/0xfffffff0_0xffffffff";
+        overrideTableViews(releasingBundle,
+                new ServiceUnitStateData(Releasing, null, broker, 1));
         overrideTableViews(splittingBundle,
                 new ServiceUnitStateData(Splitting, null, broker,
                         Map.of(childBundle1Range, Optional.empty(),
                                 childBundle2Range, Optional.empty()), 1));
-        overrideTableViews(assigningBundle1,
+        overrideTableViews(assigningBundle,
                 new ServiceUnitStateData(Assigning, broker, null, 1));
-        overrideTableViews(assigningBundle2,
-                new ServiceUnitStateData(Assigning, broker, brokerId2, 1));
         overrideTableViews(freeBundle,
                 new ServiceUnitStateData(Free, null, broker, 1));
         overrideTableViews(deletedBundle,
                 new ServiceUnitStateData(Deleted, null, broker, 1));
-        overrideTableViews(ownedBundle1,
+        overrideTableViews(ownedBundle,
                 new ServiceUnitStateData(Owned, broker, null, 1));
-        overrideTableViews(ownedBundle2,
-                new ServiceUnitStateData(Owned, broker, inactiveBroker, 1));
-        overrideTableViews(ownedBundle3,
-                new ServiceUnitStateData(Owned, inactiveBroker, broker, 1));
-
 
         // test stable metadata state
         doReturn(CompletableFuture.completedFuture(Optional.of(brokerId2)))
@@ -1617,33 +1596,16 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
         FieldUtils.writeDeclaredField(followerChannel, "inFlightStateWaitingTimeInMillis",
                 -1, true);
         ((ServiceUnitStateChannelImpl) leaderChannel)
-                .monitorOwnerships(List.of(brokerId1, brokerId2, "broker-3"));
+                .monitorOwnerships(List.of(brokerId1, brokerId2));
 
-        ServiceUnitStateChannel finalLeaderChannel = leaderChannel;
-        Awaitility.await().atMost(5, TimeUnit.SECONDS).until(() -> getCleanupJobs(finalLeaderChannel).isEmpty());
-
-
-        waitUntilNewOwner(channel2, releasingBundle1, brokerId2);
-        waitUntilNewOwner(channel2, releasingBundle2, brokerId2);
-        assertTrue(channel2.getOwnerAsync(splittingBundle).get().isEmpty());
-        waitUntilNewOwner(channel2, childBundle11, brokerId2);
-        waitUntilNewOwner(channel2, childBundle12, brokerId2);
-        waitUntilNewOwner(channel2, assigningBundle1, brokerId2);
-        waitUntilNewOwner(channel2, assigningBundle2, brokerId2);
-        assertTrue(channel2.getOwnerAsync(freeBundle).get().isEmpty());
+        waitUntilNewOwner(channel2, releasingBundle, broker);
+        waitUntilNewOwner(channel2, childBundle11, broker);
+        waitUntilNewOwner(channel2, childBundle12, broker);
+        waitUntilNewOwner(channel2, assigningBundle, brokerId2);
+        waitUntilNewOwner(channel2, ownedBundle, broker);
+        assertEquals(Optional.empty(), channel2.getOwnerAsync(freeBundle).get());
         assertTrue(channel2.getOwnerAsync(deletedBundle).isCompletedExceptionally());
-        waitUntilNewOwner(channel2, ownedBundle1, broker);
-        waitUntilNewOwner(channel2, ownedBundle2, broker);
-        waitUntilNewOwner(channel2, ownedBundle3, brokerId2);
-
-        validateMonitorCounters(leaderChannel,
-                1,
-                0,
-                6,
-                0,
-                1,
-                0,
-                0);
+        assertTrue(channel2.getOwnerAsync(splittingBundle).isCompletedExceptionally());
 
         // clean-up
         FieldUtils.writeDeclaredField(channel1,
@@ -1656,63 +1618,32 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
     @Test(priority = 19)
     public void testActiveGetOwner() throws Exception {
 
-        // case 1: the bundle owner is empty
+
+        // set the bundle owner is the broker
         String broker = brokerId2;
         String bundle = "public/owned/0xfffffff0_0xffffffff";
-        overrideTableViews(bundle, null);
-        assertEquals(Optional.empty(), channel1.getOwnerAsync(bundle).get());
-
-        // case 2: the bundle ownership is transferring, and the dst broker is not the channel owner
-        overrideTableViews(bundle,
-                new ServiceUnitStateData(Releasing, broker, brokerId1, 1));
-        assertEquals(Optional.of(broker), channel1.getOwnerAsync(bundle).get());
-
-
-        // case 3: the bundle ownership is transferring, and the dst broker is the channel owner
-        overrideTableViews(bundle,
-                new ServiceUnitStateData(Assigning, brokerId1, brokerId2, 1));
-        assertTrue(!channel1.getOwnerAsync(bundle).isDone());
-
-        // case 4: the bundle ownership is found
         overrideTableViews(bundle,
                 new ServiceUnitStateData(Owned, broker, null, 1));
         var owner = channel1.getOwnerAsync(bundle).get(5, TimeUnit.SECONDS).get();
         assertEquals(owner, broker);
 
-        // case 5: the owner lookup gets delayed
+        // simulate the owner is inactive
         var spyRegistry = spy(new BrokerRegistryImpl(pulsar));
+        doReturn(CompletableFuture.completedFuture(Optional.empty()))
+                .when(spyRegistry).lookupAsync(eq(broker));
         FieldUtils.writeDeclaredField(channel1,
                 "brokerRegistry", spyRegistry , true);
         FieldUtils.writeDeclaredField(channel1,
                 "inFlightStateWaitingTimeInMillis", 1000, true);
-        var delayedFuture = new CompletableFuture();
-        doReturn(delayedFuture).when(spyRegistry).lookupAsync(eq(broker));
-        CompletableFuture.runAsync(() -> {
-            try {
-                Thread.sleep(500);
-            } catch (InterruptedException e) {
-                Thread.currentThread().interrupt();;
-            }
-            delayedFuture.complete(Optional.of(broker));
-        });
 
-        // verify the owner eventually returns in inFlightStateWaitingTimeInMillis.
+
+        // verify getOwnerAsync times out because the owner is inactive now.
         long start = System.currentTimeMillis();
-        assertEquals(broker, channel1.getOwnerAsync(bundle).get().get());
-        long elapsed = System.currentTimeMillis() - start;
-        assertTrue(elapsed < 1000);
-
-        // case 6: the owner is inactive
-        doReturn(CompletableFuture.completedFuture(Optional.empty()))
-                .when(spyRegistry).lookupAsync(eq(broker));
-
-        // verify getOwnerAsync times out
-        start = System.currentTimeMillis();
         var ex = expectThrows(ExecutionException.class, () -> channel1.getOwnerAsync(bundle).get());
         assertTrue(ex.getCause() instanceof IllegalStateException);
         assertTrue(System.currentTimeMillis() - start >= 1000);
 
-        // case 7: the ownership cleanup(no new owner) by the leader channel
+        // simulate ownership cleanup(no selected owner) by the leader channel
         doReturn(CompletableFuture.completedFuture(Optional.empty()))
                 .when(loadManager).selectAsync(any(), any(), any());
         var leaderChannel = channel1;
@@ -1732,12 +1663,9 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
                 "inFlightStateWaitingTimeInMillis", 20 * 1000, true);
         start = System.currentTimeMillis();
         assertTrue(channel1.getOwnerAsync(bundle).get().isEmpty());
-        waitUntilState(channel1, bundle, Init);
-        waitUntilState(channel2, bundle, Init);
-
         assertTrue(System.currentTimeMillis() - start < 20_000);
 
-        // case 8: simulate ownership cleanup(brokerId1 as the new owner) by the leader channel
+        // simulate ownership cleanup(brokerId1 selected owner) by the leader channel
         overrideTableViews(bundle,
                 new ServiceUnitStateData(Owned, broker, null, 1));
         doReturn(CompletableFuture.completedFuture(Optional.of(brokerId1)))
@@ -1762,7 +1690,6 @@ public class ServiceUnitStateChannelTest extends MockedPulsarServiceBaseTest {
 
     }
 
-
     private static ConcurrentHashMap<String, CompletableFuture<Optional<String>>> getOwnerRequests(
             ServiceUnitStateChannel channel) throws IllegalAccessException {
         return (ConcurrentHashMap<String, CompletableFuture<Optional<String>>>)
