@@ -191,9 +191,9 @@ public class BrokerBkEnsemblesTests extends BkEnsemblesTestBase {
                 .build();
 
         final String ns1 = "prop/usc/crash-broker";
-        final int totalMessages = 100;
+        final int totalMessages = 99;
         final int totalDataLedgers = 5;
-        final int entriesPerLedger = totalMessages / totalDataLedgers;
+        final int entriesPerLedger = 20;
 
         try {
             admin.namespaces().createNamespace(ns1);
@@ -273,9 +273,9 @@ public class BrokerBkEnsemblesTests extends BkEnsemblesTestBase {
 
         retryStrategically((test) -> config.isAutoSkipNonRecoverableData(), 5, 100);
 
-        // (5) consumer will be able to consume 20 messages from last non-deleted ledger
+        // (5) consumer will be able to consume 19 messages from last non-deleted ledger
         consumer = client.newConsumer().topic(topic1).subscriptionName("my-subscriber-name").subscribe();
-        for (int i = 0; i < entriesPerLedger; i++) {
+        for (int i = 0; i < entriesPerLedger - 1; i++) {
             msg = consumer.receive();
             System.out.println(i);
             consumer.acknowledge(msg);
@@ -296,9 +296,9 @@ public class BrokerBkEnsemblesTests extends BkEnsemblesTestBase {
                 .statsInterval(0, TimeUnit.SECONDS)
                 .build();
 
-        final int totalMessages = 100;
+        final int totalMessages = 99;
         final int totalDataLedgers = 5;
-        final int entriesPerLedger = totalMessages / totalDataLedgers;
+        final int entriesPerLedger = 20;
 
         final String tenant = "prop";
         try {
