@@ -22,7 +22,6 @@ import static org.apache.pulsar.common.naming.SystemTopicNames.TRANSACTION_COORD
 import static org.apache.pulsar.common.naming.SystemTopicNames.TRANSACTION_COORDINATOR_LOG;
 import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.Mockito.any;
-import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
@@ -33,6 +32,7 @@ import static org.testng.Assert.assertNotNull;
 import static org.testng.Assert.assertNull;
 import static org.testng.Assert.assertTrue;
 import static org.testng.Assert.fail;
+import com.google.common.collect.Multimap;
 import com.google.common.collect.Sets;
 import com.google.gson.Gson;
 import com.google.gson.JsonArray;
@@ -44,7 +44,6 @@ import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
-import java.io.StringReader;
 import java.lang.reflect.Array;
 import java.lang.reflect.Field;
 import java.nio.charset.StandardCharsets;
@@ -75,7 +74,6 @@ import org.apache.bookkeeper.mledger.ManagedLedgerException;
 import org.apache.bookkeeper.mledger.impl.ManagedCursorImpl;
 import org.apache.bookkeeper.mledger.impl.ManagedLedgerFactoryImpl;
 import org.apache.bookkeeper.mledger.impl.ManagedLedgerImpl;
-import org.apache.commons.lang3.StringUtils;
 import org.apache.bookkeeper.mledger.impl.NullLedgerOffloader;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpGet;
@@ -87,6 +85,7 @@ import org.apache.pulsar.broker.namespace.NamespaceService;
 import org.apache.pulsar.broker.service.BrokerServiceException.PersistenceException;
 import org.apache.pulsar.broker.service.persistent.PersistentSubscription;
 import org.apache.pulsar.broker.service.persistent.PersistentTopic;
+import org.apache.pulsar.broker.stats.prometheus.PrometheusMetricsClient;
 import org.apache.pulsar.broker.stats.prometheus.PrometheusRawMetricsProvider;
 import org.apache.pulsar.client.admin.BrokerStats;
 import org.apache.pulsar.client.admin.PulsarAdminException;
@@ -107,6 +106,7 @@ import org.apache.pulsar.client.impl.ConnectionPool;
 import org.apache.pulsar.client.impl.PulsarServiceNameResolver;
 import org.apache.pulsar.client.impl.auth.AuthenticationTls;
 import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
+import org.apache.pulsar.client.impl.metrics.InstrumentProvider;
 import org.apache.pulsar.common.api.proto.CommandLookupTopicResponse;
 import org.apache.pulsar.common.api.proto.CommandPartitionedTopicMetadataResponse;
 import org.apache.pulsar.common.naming.NamespaceBundle;
@@ -1012,7 +1012,8 @@ public class BrokerServiceTest extends BrokerTestBase {
         // Using an AtomicReference in order to reset a new CountDownLatch
         AtomicReference<CountDownLatch> latchRef = new AtomicReference<>();
         latchRef.set(new CountDownLatch(1));
-        try (ConnectionPool pool = new ConnectionPool(conf, eventLoop, () -> new ClientCnx(conf, eventLoop) {
+        try (ConnectionPool pool = new ConnectionPool(InstrumentProvider.NOOP, conf, eventLoop,
+                () -> new ClientCnx(InstrumentProvider.NOOP, conf, eventLoop) {
             @Override
             protected void handleLookupResponse(CommandLookupTopicResponse lookupResult) {
                 try {
@@ -1312,67 +1313,6 @@ public class BrokerServiceTest extends BrokerTestBase {
 
     }
 
-    @Test
-    public void testCheckInactiveSubscriptionWhenNoMessageToAck() throws Exception {
-        String namespace = "prop/testInactiveSubscriptionWhenNoMessageToAck";
-
-        try {
-            admin.namespaces().createNamespace(namespace);
-        } catch (PulsarAdminException.ConflictException e) {
-            // Ok.. (if test fails intermittently and namespace is already created)
-        }
-
-        String topic = "persistent://" + namespace + "/my-topic";
-        Producer<byte[]> producer = pulsarClient.newProducer().topic(topic).create();
-        producer.send("test".getBytes());
-        producer.close();
-
-        // create consumer to consume all messages
-        Consumer<byte[]> consumer = pulsarClient.newConsumer().topic(topic).subscriptionName("sub1")
-                .subscriptionInitialPosition(SubscriptionInitialPosition.Earliest).subscribe();
-        consumer.acknowledge(consumer.receive());
-
-        Optional<Topic> topicOptional = pulsar.getBrokerService().getTopic(topic, true).get();
-        assertTrue(topicOptional.isPresent());
-        PersistentTopic persistentTopic = (PersistentTopic) topicOptional.get();
-
-        // wait for 1s, but consumer is still connected all the time.
-        // so subscription should not be deleted.
-        Thread.sleep(1000);
-        persistentTopic.checkInactiveSubscriptions(1000);
-        PersistentTopic finalPersistentTopic = persistentTopic;
-        Awaitility.await().pollDelay(3, TimeUnit.SECONDS).until(() ->
-                finalPersistentTopic.getSubscriptions().containsKey("sub1"));
-        PersistentSubscription sub = persistentTopic.getSubscription("sub1");
-
-        // shutdown pulsar ungracefully
-        // disable the updateLastActive method to simulate the ungraceful shutdown
-        ManagedCursorImpl cursor = (ManagedCursorImpl) sub.getCursor();
-        ManagedCursorImpl spyCursor = Mockito.spy(cursor);
-        doNothing().when(spyCursor).updateLastActive();
-        Field cursorField = PersistentSubscription.class.getDeclaredField("cursor");
-        cursorField.setAccessible(true);
-        cursorField.set(sub, spyCursor);
-
-        // restart pulsar
-        consumer.close();
-        restartBroker();
-
-        admin.lookups().lookupTopic(topic);
-        topicOptional = pulsar.getBrokerService().getTopic(topic, true).get();
-        assertTrue(topicOptional.isPresent());
-        persistentTopic = (PersistentTopic) topicOptional.get();
-        persistentTopic.checkInactiveSubscriptions(1000);
-
-        // check if subscription is still present
-        PersistentTopic finalPersistentTopic1 = persistentTopic;
-        Awaitility.await().pollDelay(3, TimeUnit.SECONDS).until(() ->
-                finalPersistentTopic1.getSubscriptions().containsKey("sub1"));
-        sub = persistentTopic.getSubscription("sub1");
-        assertNotNull(sub);
-    }
-
-
     /**
      * Verifies brokerService should not have deadlock and successfully remove topic from topicMap on topic-failure and
      * it should not introduce deadlock while performing it.
@@ -1682,35 +1622,20 @@ public class BrokerServiceTest extends BrokerTestBase {
         });
 
         // Do test
-        Thread.sleep(1000 * 3);
         CompletableFuture<Producer<byte[]>> producer = pulsarClient.newProducer().topic(topic).createAsync();
         JerseyClient httpClient = JerseyClientBuilder.createClient();
         Awaitility.await().until(() -> {
             String response = httpClient.target(pulsar.getWebServiceAddress()).path("/metrics/")
                     .request().get(String.class);
-            BufferedReader reader = new BufferedReader(new StringReader(response));
-            String line;
-            String metricsLine = null;
-            while ((line = reader.readLine()) != null) {
-                if (StringUtils.isBlank(line)) {
-                    continue;
-                }
-                if (line.startsWith("#")) {
-                    continue;
-                }
-                if (line.contains("topic_load_failed")) {
-                    metricsLine = line;
-                    break;
-                }
-            }
-            log.info("topic_load_failed: {}", metricsLine);
-            if (metricsLine == null) {
+            Multimap<String, PrometheusMetricsClient.Metric> metricMap = PrometheusMetricsClient.parseMetrics(response);
+            if (!metricMap.containsKey("pulsar_topic_load_failed_count")) {
                 return false;
             }
-            reader.close();
-            String[] parts = metricsLine.split(" ");
-            Double value = Double.valueOf(parts[parts.length - 1]);
-            return value >= 1D;
+            double topic_load_failed_count = 0;
+            for (PrometheusMetricsClient.Metric metric : metricMap.get("pulsar_topic_load_failed_count")) {
+                topic_load_failed_count += metric.value;
+            }
+            return topic_load_failed_count >= 1D;
         });
 
         // Remove the injection.
@@ -1746,29 +1671,15 @@ public class BrokerServiceTest extends BrokerTestBase {
         Awaitility.await().until(() -> {
             String response = httpClient.target(pulsar.getWebServiceAddress()).path("/metrics/")
                     .request().get(String.class);
-            BufferedReader reader = new BufferedReader(new StringReader(response));
-            String line;
-            String metricsLine = null;
-            while ((line = reader.readLine()) != null) {
-                if (StringUtils.isBlank(line)) {
-                    continue;
-                }
-                if (line.startsWith("#")) {
-                    continue;
-                }
-                if (line.contains("topic_load_failed")) {
-                    metricsLine = line;
-                    break;
-                }
-            }
-            log.info("topic_load_failed: {}", metricsLine);
-            if (metricsLine == null) {
+            Multimap<String, PrometheusMetricsClient.Metric> metricMap = PrometheusMetricsClient.parseMetrics(response);
+            if (!metricMap.containsKey("pulsar_topic_load_failed_count")) {
                 return false;
             }
-            reader.close();
-            String[] parts = metricsLine.split(" ");
-            Double value = Double.valueOf(parts[parts.length - 1]);
-            return value >= 1D;
+            double topic_load_failed_count = 0;
+            for (PrometheusMetricsClient.Metric metric : metricMap.get("pulsar_topic_load_failed_count")) {
+                topic_load_failed_count += metric.value;
+            }
+            return topic_load_failed_count >= 1D;
         });
 
         // Remove the injection.
