@@ -19,7 +19,6 @@
 package org.apache.pulsar.broker.service;
 
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertFalse;
 import static org.testng.Assert.assertNotNull;
@@ -28,31 +27,19 @@ import static org.testng.Assert.assertTrue;
 import static org.testng.Assert.fail;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.HashMap;
 import java.util.HashSet;
-import java.util.LinkedHashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.Function;
 import lombok.Cleanup;
 import lombok.extern.slf4j.Slf4j;
-import org.apache.bookkeeper.mledger.ManagedCursor;
-import org.apache.bookkeeper.mledger.ManagedLedger;
-import org.apache.bookkeeper.mledger.ManagedLedgerConfig;
-import org.apache.bookkeeper.mledger.Position;
-import org.apache.bookkeeper.mledger.proto.MLDataFormats;
-import org.apache.commons.lang3.ArrayUtils;
 import org.apache.pulsar.broker.service.persistent.PersistentSubscription;
 import org.apache.pulsar.broker.service.persistent.PersistentTopic;
 import org.apache.pulsar.client.admin.PulsarAdminException;
-import org.apache.pulsar.client.api.InjectedClientCnxClientBuilder;
 import org.apache.pulsar.client.api.Message;
 import org.apache.pulsar.client.api.MessageId;
 import org.apache.pulsar.client.api.MessageRoutingMode;
@@ -61,19 +48,12 @@ import org.apache.pulsar.client.api.PulsarClient;
 import org.apache.pulsar.client.api.PulsarClientException;
 import org.apache.pulsar.client.api.Reader;
 import org.apache.pulsar.client.api.Schema;
-import org.apache.pulsar.client.api.SubscriptionInitialPosition;
 import org.apache.pulsar.client.api.SubscriptionType;
 import org.apache.pulsar.client.impl.BatchMessageIdImpl;
-import org.apache.pulsar.client.impl.ClientBuilderImpl;
-import org.apache.pulsar.client.impl.ClientCnx;
 import org.apache.pulsar.client.impl.MessageIdImpl;
-import org.apache.pulsar.client.impl.TopicMessageIdImpl;
-import org.apache.pulsar.common.api.proto.CommandError;
 import org.apache.pulsar.common.naming.TopicName;
-import org.apache.pulsar.common.policies.data.RetentionPolicies;
 import org.apache.pulsar.common.util.RelativeTimeUtil;
 import org.awaitility.Awaitility;
-import org.testng.Assert;
 import org.testng.annotations.AfterClass;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
@@ -85,11 +65,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
     @BeforeClass
     @Override
     protected void setup() throws Exception {
-        conf.setManagedLedgerMinLedgerRolloverTimeMinutes(0);
-        conf.setManagedLedgerMaxEntriesPerLedger(10);
-        conf.setDefaultRetentionSizeInMB(100);
-        conf.setDefaultRetentionTimeInMinutes(100);
-        conf.setAutoSkipNonRecoverableData(true);
         super.baseSetup();
         conf.setAcknowledgmentAtBatchIndexLevelEnabled(true);
     }
@@ -104,11 +79,9 @@ public class SubscriptionSeekTest extends BrokerTestBase {
     public void testSeek() throws Exception {
         final String topicName = "persistent://prop/use/ns-abc/testSeek";
 
-        @Cleanup
         Producer<byte[]> producer = pulsarClient.newProducer().topic(topicName).create();
 
         // Disable pre-fetch in consumer to track the messages received
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<byte[]> consumer = pulsarClient.newConsumer().topic(topicName)
                 .subscriptionName("my-subscription").receiverQueueSize(0).subscribe();
 
@@ -158,13 +131,11 @@ public class SubscriptionSeekTest extends BrokerTestBase {
 
     @Test
     public void testSeekIsByReceive() throws PulsarClientException {
-        final String topicName = "persistent://prop/use/ns-abc/testSeekIsByReceive";
+        final String topicName = "persistent://prop/use/ns-abc/testSeek";
 
-        @Cleanup
         Producer<byte[]> producer = pulsarClient.newProducer().topic(topicName).create();
 
         String subscriptionName = "my-subscription";
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<byte[]> consumer = pulsarClient.newConsumer().topic(topicName)
                 .subscriptionName(subscriptionName)
                 .subscribe();
@@ -186,7 +157,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         final String topicName = "persistent://prop/use/ns-abcd/testSeekForBatch";
         String subscriptionName = "my-subscription-batch";
 
-        @Cleanup
         Producer<String> producer = pulsarClient.newProducer(Schema.STRING)
                 .enableBatching(true)
                 .batchingMaxMessages(3)
@@ -213,7 +183,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         producer.close();
 
 
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING)
                 .topic(topicName)
                 .subscriptionName(subscriptionName)
@@ -244,7 +213,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         final String topicName = "persistent://prop/use/ns-abcd/testSeekForBatchMessageAndSpecifiedBatchIndex";
         String subscriptionName = "my-subscription-batch";
 
-        @Cleanup
         Producer<String> producer = pulsarClient.newProducer(Schema.STRING)
                 .enableBatching(true)
                 .batchingMaxMessages(3)
@@ -289,7 +257,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
                 .serviceUrl(lookupUrl.toString())
                 .build();
 
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<String> consumer = newPulsarClient.newConsumer(Schema.STRING)
                 .topic(topicName)
                 .subscriptionName(subscriptionName)
@@ -326,7 +293,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         final String topicName = "persistent://prop/use/ns-abcd/testSeekForBatchByAdmin-" + UUID.randomUUID().toString();
         String subscriptionName = "my-subscription-batch";
 
-        @Cleanup
         Producer<String> producer = pulsarClient.newProducer(Schema.STRING)
                 .enableBatching(true)
                 .batchingMaxMessages(3)
@@ -352,7 +318,7 @@ public class SubscriptionSeekTest extends BrokerTestBase {
 
         producer.close();
 
-        @Cleanup
+
         org.apache.pulsar.client.api.Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING)
                 .topic(topicName)
                 .subscriptionName(subscriptionName)
@@ -408,7 +374,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         final String topicName = "persistent://prop/use/ns-abc/testConcurrentReset_" + System.currentTimeMillis();
         final String subscriptionName = "test-sub-name";
 
-        @Cleanup
         Producer<byte[]> producer = pulsarClient.newProducer().topic(topicName).create();
 
         admin.topics().createSubscription(topicName, subscriptionName, MessageId.earliest);
@@ -458,7 +423,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         final String topicName = "persistent://prop/use/ns-abc/testSeekPartitions";
 
         admin.topics().createPartitionedTopic(topicName, 2);
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<byte[]> consumer = pulsarClient.newConsumer().topic(topicName)
                 .subscriptionName("my-subscription").subscribe();
 
@@ -469,22 +433,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         }
     }
 
-    @Test
-    public void testSeekWithNonOwnerTopicMessage() throws Exception {
-        final String topicName = "persistent://prop/use/ns-abc/testNonOwnerTopicMessage";
-
-        admin.topics().createPartitionedTopic(topicName, 2);
-        @Cleanup
-        org.apache.pulsar.client.api.Consumer<byte[]> consumer = pulsarClient.newConsumer().topic(topicName)
-                .subscriptionName("my-subscription").subscribe();
-        assertThatThrownBy(
-                // seek with a TopicMessageIdImpl that has a null topic.
-                () -> consumer.seek(new TopicMessageIdImpl(null, new BatchMessageIdImpl(123L, 345L, 566, 789)))
-            )
-            .isInstanceOf(PulsarClientException.class)
-            .hasMessage("The owner topic is null");
-    }
-
     @Test
     public void testSeekTime() throws Exception {
         final String topicName = "persistent://prop/use/ns-abc/testSeekTime";
@@ -492,11 +440,9 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         long resetTimeInMillis = TimeUnit.SECONDS
                 .toMillis(RelativeTimeUtil.parseRelativeTimeInSeconds(resetTimeStr));
 
-        @Cleanup
         Producer<byte[]> producer = pulsarClient.newProducer().topic(topicName).create();
 
         // Disable pre-fetch in consumer to track the messages received
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<byte[]> consumer = pulsarClient.newConsumer().topic(topicName)
                 .subscriptionName("my-subscription").receiverQueueSize(0).subscribe();
 
@@ -523,194 +469,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         assertEquals(sub.getNumberOfEntriesInBacklog(false), 10);
     }
 
-    @Test(timeOut = 30_000)
-    public void testSeekByTimestamp() throws Exception {
-        String topicName = "persistent://prop/use/ns-abc/testSeekByTimestamp";
-        admin.topics().createNonPartitionedTopic(topicName);
-        admin.topics().createSubscription(topicName, "my-sub", MessageId.earliest);
-
-        @Cleanup
-        Producer<String> producer =
-                pulsarClient.newProducer(Schema.STRING).topic(topicName).enableBatching(false).create();
-        for (int i = 0; i < 25; i++) {
-            producer.send(("message-" + i));
-            Thread.sleep(10);
-        }
-
-        PersistentTopic topic = (PersistentTopic) pulsar.getBrokerService().getTopic(topicName, false).get().get();
-
-        Map<Long, MessageId> timestampToMessageId = new HashMap<>();
-        @Cleanup
-        Reader<String> reader = pulsarClient.newReader(Schema.STRING).topic(topicName).startMessageId(MessageId.earliest).create();
-        while (reader.hasMessageAvailable()) {
-           Message<String> message = reader.readNext();
-              timestampToMessageId.put(message.getPublishTime(), message.getMessageId());
-        }
-
-        Assert.assertEquals(timestampToMessageId.size(), 25);
-
-        PersistentSubscription subscription = topic.getSubscription("my-sub");
-        ManagedCursor cursor = subscription.getCursor();
-
-        @Cleanup
-        org.apache.pulsar.client.api.Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING)
-                .topic(topicName).subscriptionName("my-sub").subscriptionInitialPosition(SubscriptionInitialPosition.Earliest).subscribe();
-        long[] timestamps = timestampToMessageId.keySet().stream().mapToLong(Long::longValue).toArray();
-        ArrayUtils.shuffle(timestamps);
-        for (long timestamp : timestamps) {
-            MessageIdImpl messageId = (MessageIdImpl) timestampToMessageId.get(timestamp);
-            consumer.seek(timestamp);
-            Position readPosition = cursor.getReadPosition();
-            Assert.assertEquals(readPosition.getLedgerId(), messageId.getLedgerId());
-            Assert.assertEquals(readPosition.getEntryId(), messageId.getEntryId());
-        }
-    }
-
-    @Test(timeOut = 30_000)
-    public void testSeekByTimestampWithSkipNonRecoverableData() throws Exception {
-        String topicName = "persistent://prop/use/ns-abc/testSeekByTimestampWithSkipNonRecoverableData";
-        admin.topics().createNonPartitionedTopic(topicName);
-        admin.topics().createSubscription(topicName, "my-sub", MessageId.earliest);
-
-        @Cleanup
-        Producer<String> producer =
-            pulsarClient.newProducer(Schema.STRING).topic(topicName).enableBatching(false).create();
-        for (int i = 0; i < 55; i++) {
-            producer.send(("message-" + i));
-            Thread.sleep(10);
-        }
-
-        Map<Long, MessageIdImpl> timestampToMessageId = new HashMap<>();
-        List<Long> ledgerIds = new ArrayList<>();
-        @Cleanup
-        Reader<String> reader =
-            pulsarClient.newReader(Schema.STRING).topic(topicName).startMessageId(MessageId.earliest).create();
-        while (reader.hasMessageAvailable()) {
-            Message<String> message = reader.readNext();
-            log.info("message: {} ----- {}", message.getMessageId(), message.getPublishTime());
-            timestampToMessageId.put(message.getPublishTime(), (MessageIdImpl) message.getMessageId());
-            long ledgerId = ((MessageIdImpl) message.getMessageId()).getLedgerId();
-            if (!ledgerIds.contains(ledgerId)) {
-                ledgerIds.add(ledgerId);
-            }
-        }
-
-        Assert.assertEquals(timestampToMessageId.size(), 55);
-
-        LinkedHashSet<Long> deletedLedgerIds = new LinkedHashSet<>();
-        deletedLedgerIds.add(ledgerIds.get(0));
-        deletedLedgerIds.add(ledgerIds.get(ledgerIds.size() - 1));
-        int mid = ledgerIds.size() / 2;
-        deletedLedgerIds.add(ledgerIds.get(mid));
-
-        for (Long deletedLedgerId : deletedLedgerIds) {
-            pulsar.getBookKeeperClient().deleteLedger(deletedLedgerId);
-            log.info("delete ledger: {}", deletedLedgerId);
-        }
-
-        admin.topics().unload(topicName);
-
-        @Cleanup
-        org.apache.pulsar.client.api.Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING)
-            .receiverQueueSize(0)
-            .topic(topicName).subscriptionName("my-sub")
-            .subscriptionInitialPosition(SubscriptionInitialPosition.Earliest).subscribe();
-        long[] timestamps = timestampToMessageId.keySet().stream().mapToLong(Long::longValue).toArray();
-
-        Arrays.sort(timestamps);
-
-        timestampToMessageId.values().removeIf(messageId -> deletedLedgerIds.contains(messageId.getLedgerId()));
-
-        final int lastNonRecoverableEntryNums = 5;
-
-        for (int i = 0; i < timestamps.length - lastNonRecoverableEntryNums; i++) {
-            MessageIdImpl nextValidMessageId = timestampToMessageId.get(timestamps[i]);
-            int l = i;
-            while (nextValidMessageId == null) {
-                nextValidMessageId = timestampToMessageId.get(timestamps[l++]);
-            }
-
-            consumer.seek(timestamps[i]);
-            Message<String> receive = consumer.receive();
-
-            MessageIdImpl msgId = (MessageIdImpl) receive.getMessageId();
-            Assert.assertEquals(msgId.getLedgerId(), nextValidMessageId.getLedgerId());
-            Assert.assertEquals(msgId.getEntryId(), nextValidMessageId.getEntryId());
-        }
-
-        MessageIdImpl lastMessageId = (MessageIdImpl) producer.send(("message-last"));
-
-        for (int i = timestamps.length - lastNonRecoverableEntryNums; i < timestamps.length; i++) {
-            consumer.seek(timestamps[i]);
-            Message<String> receive = consumer.receive();
-
-            MessageIdImpl msgId = (MessageIdImpl) receive.getMessageId();
-            Assert.assertEquals(msgId.getLedgerId(), lastMessageId.getLedgerId());
-            Assert.assertEquals(msgId.getEntryId(), lastMessageId.getEntryId());
-        }
-    }
-
-    @Test(timeOut = 30_000)
-    public void testSeekByTimestampWithLedgerTrim() throws Exception {
-        String topicName = "persistent://prop/use/ns-abc/testSeekByTimestampWithLedgerTrim";
-        admin.topics().createNonPartitionedTopic(topicName);
-        admin.topics().createSubscription(topicName, "my-sub", MessageId.earliest);
-
-        @Cleanup
-        Producer<String> producer =
-                pulsarClient.newProducer(Schema.STRING).topic(topicName).enableBatching(false).create();
-        for (int i = 0; i < 25; i++) {
-            producer.send(("message-" + i));
-            Thread.sleep(10);
-        }
-
-        PersistentTopic topic = (PersistentTopic) pulsar.getBrokerService().getTopic(topicName, false).get().get();
-        ManagedLedger ledger = topic.getManagedLedger();
-        ManagedLedgerConfig config = ledger.getConfig();
-        config.setRetentionTime(0, TimeUnit.SECONDS);
-        config.setRetentionSizeInMB(0);
-
-        Map<Long, MessageId> timestampToMessageId = new HashMap<>();
-        @Cleanup
-        Reader<String> reader = pulsarClient.newReader(Schema.STRING).topic(topicName).startMessageId(MessageId.earliest).create();
-        while (reader.hasMessageAvailable()) {
-            Message<String> message = reader.readNext();
-            timestampToMessageId.put(message.getPublishTime(), message.getMessageId());
-        }
-
-        Assert.assertEquals(timestampToMessageId.size(), 25);
-
-        PersistentSubscription subscription = topic.getSubscription("my-sub");
-        ManagedCursor cursor = subscription.getCursor();
-
-        @Cleanup
-        org.apache.pulsar.client.api.Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING)
-                .topic(topicName).subscriptionName("my-sub").subscriptionInitialPosition(SubscriptionInitialPosition.Earliest).subscribe();
-        long[] timestamps = timestampToMessageId.keySet().stream().mapToLong(Long::longValue).toArray();
-        ArrayUtils.shuffle(timestamps);
-        boolean enterLedgerTrimmedBranch = false;
-        for (long timestamp : timestamps) {
-            MessageIdImpl messageId = (MessageIdImpl) timestampToMessageId.get(timestamp);
-            consumer.seek(timestamp);
-            CompletableFuture<?> trimFuture = new CompletableFuture<>();
-            ledger.trimConsumedLedgersInBackground(trimFuture);
-            trimFuture.get();
-            Position readPosition = cursor.getReadPosition();
-            Map.Entry<Long, MLDataFormats.ManagedLedgerInfo.LedgerInfo> firstLedger = ledger.getLedgersInfo().firstEntry();
-            Assert.assertNotNull(firstLedger);
-            if (firstLedger.getKey() > messageId.getLedgerId()) {
-                Assert.assertEquals(readPosition.getLedgerId(), firstLedger.getKey());
-                Assert.assertEquals(readPosition.getEntryId(), 0);
-                enterLedgerTrimmedBranch = true;
-            } else {
-                Assert.assertEquals(readPosition.getLedgerId(), messageId.getLedgerId());
-                Assert.assertEquals(readPosition.getEntryId(), messageId.getEntryId());
-            }
-        }
-        // May have a chance to cause flaky test, because the result of `ArrayUtils.shuffle(timestamps);` is random.
-        Assert.assertTrue(enterLedgerTrimmedBranch);
-    }
-
     @Test
     public void testSeekTimeByFunction() throws Exception {
         final String topicName = "persistent://prop/use/ns-abc/test" + UUID.randomUUID();
@@ -718,7 +476,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         int msgNum = 20;
         admin.topics().createPartitionedTopic(topicName, partitionNum);
         creatProducerAndSendMsg(topicName, msgNum);
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<String> consumer = pulsarClient
                 .newConsumer(Schema.STRING).startMessageIdInclusive()
                 .topic(topicName).subscriptionName("my-sub").subscribe();
@@ -766,7 +523,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         long resetTimeInMillis = TimeUnit.SECONDS
                 .toMillis(RelativeTimeUtil.parseRelativeTimeInSeconds(resetTimeStr));
         admin.topics().createPartitionedTopic(topicName, partitions);
-        @Cleanup
         Producer<byte[]> producer = pulsarClient.newProducer().topic(topicName).create();
         // Disable pre-fetch in consumer to track the messages received
         org.apache.pulsar.client.api.Consumer<byte[]> consumer = pulsarClient.newConsumer().topic(topicName)
@@ -820,14 +576,12 @@ public class SubscriptionSeekTest extends BrokerTestBase {
     public void testShouldCloseAllConsumersForMultipleConsumerDispatcherWhenSeek() throws Exception {
         final String topicName = "persistent://prop/use/ns-abc/testShouldCloseAllConsumersForMultipleConsumerDispatcherWhenSeek";
         // Disable pre-fetch in consumer to track the messages received
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<byte[]> consumer1 = pulsarClient.newConsumer()
                 .topic(topicName)
                 .subscriptionType(SubscriptionType.Shared)
                 .subscriptionName("my-subscription")
                 .subscribe();
 
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<byte[]> consumer2 = pulsarClient.newConsumer()
                 .topic(topicName)
                 .subscriptionType(SubscriptionType.Shared)
@@ -854,20 +608,20 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         for (Consumer consumer : consumers) {
             assertFalse(connectedSinceSet.contains(consumer.getStats().getConnectedSince()));
         }
+        consumer1.close();
+        consumer2.close();
     }
 
     @Test
     public void testOnlyCloseActiveConsumerForSingleActiveConsumerDispatcherWhenSeek() throws Exception {
         final String topicName = "persistent://prop/use/ns-abc/testOnlyCloseActiveConsumerForSingleActiveConsumerDispatcherWhenSeek";
         // Disable pre-fetch in consumer to track the messages received
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<byte[]> consumer1 = pulsarClient.newConsumer()
                 .topic(topicName)
                 .subscriptionType(SubscriptionType.Failover)
                 .subscriptionName("my-subscription")
                 .subscribe();
 
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<byte[]> consumer2 = pulsarClient.newConsumer()
                 .topic(topicName)
                 .subscriptionType(SubscriptionType.Failover)
@@ -907,13 +661,11 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         int msgNum = 160;
         admin.topics().createPartitionedTopic(topicName, partitionNum);
         creatProducerAndSendMsg(topicName, msgNum);
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<String> consumer = pulsarClient
                 .newConsumer(Schema.STRING).startMessageIdInclusive()
                 .topic(topicName).subscriptionName("my-sub").subscribe();
 
         TopicName partitionedTopic = TopicName.get(topicName);
-        @Cleanup
         Reader<String> reader = pulsarClient.newReader(Schema.STRING)
                 .startMessageId(MessageId.earliest)
                 .topic(partitionedTopic.getPartition(0).toString()).create();
@@ -962,11 +714,12 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         for (MessageId messageId : msgNotIn) {
             assertFalse(received.contains(messageId));
         }
+        reader.close();
+        consumer.close();
     }
 
     private List<MessageId> creatProducerAndSendMsg(String topic, int msgNum) throws Exception {
         List<MessageId> messageIds = new ArrayList<>();
-        @Cleanup
         Producer<String> producer = pulsarClient
                 .newProducer(Schema.STRING)
                 .enableBatching(false)
@@ -975,6 +728,7 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         for (int i = 0; i < msgNum; i++) {
             messageIds.add(producer.send("msg" + i));
         }
+        producer.close();
         return messageIds;
     }
 
@@ -995,7 +749,6 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         MessageId msgIdInTopic2Partition0 = admin.topics().getLastMessageId(topic2.getPartition(0).toString());
         MessageId msgIdInTopic2Partition2 = admin.topics().getLastMessageId(topic2.getPartition(2).toString());
 
-        @Cleanup
         org.apache.pulsar.client.api.Consumer<String> consumer = pulsarClient
                 .newConsumer(Schema.STRING).startMessageIdInclusive()
                 .topics(Arrays.asList(topicName, topicName2)).subscriptionName("my-sub").subscribe();
@@ -1028,75 +781,10 @@ public class SubscriptionSeekTest extends BrokerTestBase {
         assertEquals(count, (msgInTopic1Partition0 + msgInTopic1Partition1 + msgInTopic1Partition2) * 2);
     }
 
-    @Test
-    public void testSeekWillNotEncounteredFencedError() throws Exception {
-        String topicName = "persistent://prop/ns-abc/my-topic2";
-        admin.topics().createNonPartitionedTopic(topicName);
-        admin.topicPolicies().setRetention(topicName, new RetentionPolicies(3600, -1));
-        // Create a pulsar client with a subscription fenced counter.
-        ClientBuilderImpl clientBuilder = (ClientBuilderImpl) PulsarClient.builder().serviceUrl(lookupUrl.toString());
-        AtomicInteger receivedFencedErrorCounter = new AtomicInteger();
-        // Count switch: Default off, turn on again before seek starts.
-        final AtomicBoolean countAfterSeek = new AtomicBoolean(false);
-        @Cleanup
-        PulsarClient client = InjectedClientCnxClientBuilder.create(clientBuilder, (conf, eventLoopGroup) ->
-                new ClientCnx(conf, eventLoopGroup) {
-                    protected void handleError(CommandError error) {
-                        if (error.getMessage() != null && error.getMessage().contains("Subscription is fenced")
-                                && countAfterSeek.get()) {
-                            receivedFencedErrorCounter.incrementAndGet();
-                        }
-                        super.handleError(error);
-                    }
-                });
-
-        // publish some messages.
-        @Cleanup
-        org.apache.pulsar.client.api.Consumer<String> consumer = client.newConsumer(Schema.STRING)
-                .topic(topicName)
-                .subscriptionName("s1")
-                .subscribe();
-
-        @Cleanup
-        Producer<String> producer = client.newProducer(Schema.STRING)
-                .topic(topicName).create();
-        MessageIdImpl msgId1 = (MessageIdImpl) producer.send("0");
-        for (int i = 1; i < 11; i++) {
-            admin.topics().unload(topicName);
-            producer.send(i + "");
-        }
-
-        // Inject a delay for reset-cursor.
-        mockZooKeeper.delay(3000, (op, path) -> {
-            if (path.equals("/managed-ledgers/prop/ns-abc/persistent/my-topic2/s1")) {
-                return op.toString().equalsIgnoreCase("SET");
-            }
-            return false;
-        });
-
-        // Verify: consumer will not receive "subscription fenced" error after a seek.
-        for (int i = 1; i < 11; i++) {
-            Message<String> msg = consumer.receive(2, TimeUnit.SECONDS);
-            assertNotNull(msg);
-            consumer.acknowledge(msg);
-        }
-        countAfterSeek.set(true);
-        consumer.seek(msgId1);
-        Awaitility.await().untilAsserted(() -> assertTrue(consumer.isConnected()));
-        assertEquals(receivedFencedErrorCounter.get(), 0);
-
-        // cleanup.
-        producer.close();
-        consumer.close();
-        client.close();
-        admin.topics().delete(topicName);
-    }
-
     @Test
     public void testExceptionBySeekFunction() throws Exception {
         final String topicName = "persistent://prop/use/ns-abc/test" + UUID.randomUUID();
         creatProducerAndSendMsg(topicName,10);
-        @Cleanup
         org.apache.pulsar.client.api.Consumer consumer = pulsarClient
                 .newConsumer()
                 .topic(topicName).subscriptionName("my-sub").subscribe();
