@@ -18,6 +18,8 @@
  */
 package org.apache.pulsar.broker.service.persistent;
 
+import static org.apache.pulsar.broker.stats.prometheus.PrometheusMetricsClient.Metric;
+import static org.apache.pulsar.broker.stats.prometheus.PrometheusMetricsClient.parseMetrics;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyInt;
 import static org.mockito.Mockito.doAnswer;
@@ -64,7 +66,6 @@ import org.apache.bookkeeper.mledger.AsyncCallbacks;
 import org.apache.bookkeeper.mledger.ManagedCursor;
 import org.apache.bookkeeper.mledger.ManagedLedger;
 import org.apache.bookkeeper.mledger.impl.ManagedCursorContainer;
-import org.apache.bookkeeper.mledger.impl.ManagedCursorImpl;
 import org.apache.bookkeeper.mledger.impl.ManagedLedgerImpl;
 import org.apache.bookkeeper.mledger.impl.PositionImpl;
 import org.apache.pulsar.PrometheusMetricsTestUtil;
@@ -72,7 +73,6 @@ import org.apache.pulsar.broker.service.BrokerService;
 import org.apache.pulsar.broker.service.BrokerTestBase;
 import org.apache.pulsar.broker.service.Topic;
 import org.apache.pulsar.broker.service.TopicPoliciesService;
-import org.apache.pulsar.broker.stats.PrometheusMetricsTest;
 import org.apache.pulsar.client.admin.PulsarAdminException;
 import org.apache.pulsar.client.api.Consumer;
 import org.apache.pulsar.client.api.Message;
@@ -449,14 +449,14 @@ public class PersistentTopicTest extends BrokerTestBase {
         PrometheusMetricsTestUtil.generate(pulsar, exposeTopicLevelMetrics, true, true, output);
         String metricsStr = output.toString(StandardCharsets.UTF_8);
 
-        Multimap<String, PrometheusMetricsTest.Metric> metricsMap = PrometheusMetricsTest.parseMetrics(metricsStr);
-        Collection<PrometheusMetricsTest.Metric> metrics = metricsMap.get("pulsar_delayed_message_index_size_bytes");
+        Multimap<String, Metric> metricsMap = parseMetrics(metricsStr);
+        Collection<Metric> metrics = metricsMap.get("pulsar_delayed_message_index_size_bytes");
         Assert.assertTrue(metrics.size() > 0);
 
         int topicLevelNum = 0;
         int namespaceLevelNum = 0;
         int subscriptionLevelNum = 0;
-        for (PrometheusMetricsTest.Metric metric : metrics) {
+        for (Metric metric : metrics) {
             if (exposeTopicLevelMetrics && metric.tags.get("topic").equals(topic)) {
                 Assert.assertTrue(metric.value > 0);
                 topicLevelNum++;
@@ -754,30 +754,6 @@ public class PersistentTopicTest extends BrokerTestBase {
         admin.topics().delete(topicName);
     }
 
-    @Test
-    public void testCursorGetConfigAfterTopicPoliciesChanged() throws Exception {
-        final String topicName = "persistent://prop/ns-abc/" + UUID.randomUUID();
-        final String subName = "test_sub";
-
-        @Cleanup
-        Consumer<byte[]> subscribe = pulsarClient.newConsumer().topic(topicName).subscriptionName(subName).subscribe();
-        PersistentTopic persistentTopic =
-                (PersistentTopic) pulsar.getBrokerService().getTopic(topicName, false).join().get();
-        PersistentSubscription subscription = persistentTopic.getSubscription(subName);
-
-        int maxConsumers = 100;
-        admin.topicPolicies().setMaxConsumers(topicName, 100);
-        Awaitility.await().untilAsserted(() -> {
-            assertEquals(admin.topicPolicies().getMaxConsumers(topicName, false), maxConsumers);
-        });
-
-        ManagedCursorImpl cursor = (ManagedCursorImpl) subscription.getCursor();
-        assertEquals(cursor.getConfig(), persistentTopic.getManagedLedger().getConfig());
-
-        subscribe.close();
-        admin.topics().delete(topicName);
-    }
-
     @Test
     public void testAddWaitingCursorsForNonDurable() throws Exception {
         final String ns = "prop/ns-test";
