@@ -19,6 +19,7 @@
 package org.apache.pulsar.client.impl;
 
 import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.spy;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertSame;
 import static org.testng.Assert.assertTrue;
@@ -27,8 +28,6 @@ import static org.testng.Assert.fail;
 import com.google.common.collect.Lists;
 
 import java.time.Duration;
-import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import java.util.Optional;
 import java.util.concurrent.CompletableFuture;
@@ -36,6 +35,7 @@ import java.util.concurrent.TimeUnit;
 import java.util.regex.Pattern;
 import java.util.stream.IntStream;
 
+import io.netty.util.Timeout;
 import org.apache.pulsar.broker.BrokerTestUtil;
 import org.apache.pulsar.broker.namespace.NamespaceService;
 import org.apache.pulsar.client.api.Consumer;
@@ -49,11 +49,10 @@ import org.apache.pulsar.client.api.PulsarClientException;
 import org.apache.pulsar.client.api.RegexSubscriptionMode;
 import org.apache.pulsar.client.api.Schema;
 import org.apache.pulsar.client.api.SubscriptionType;
+import org.apache.pulsar.client.impl.metrics.InstrumentProvider;
 import org.apache.pulsar.common.api.proto.BaseCommand;
-import org.apache.pulsar.common.api.proto.CommandGetTopicsOfNamespace;
 import org.apache.pulsar.common.api.proto.CommandWatchTopicListSuccess;
 import org.apache.pulsar.common.naming.NamespaceName;
-import org.apache.pulsar.common.naming.TopicName;
 import org.apache.pulsar.common.policies.data.TenantInfoImpl;
 import org.awaitility.Awaitility;
 import org.awaitility.reflect.WhiteboxImpl;
@@ -813,7 +812,7 @@ public class PatternTopicsConsumerImplTest extends ProducerConsumerBase {
     private PulsarClient createDelayWatchTopicsClient() throws Exception {
         ClientBuilderImpl clientBuilder = (ClientBuilderImpl) PulsarClient.builder().serviceUrl(lookupUrl.toString());
         return InjectedClientCnxClientBuilder.create(clientBuilder,
-            (conf, eventLoopGroup) -> new ClientCnx(conf, eventLoopGroup) {
+            (conf, eventLoopGroup) -> new ClientCnx(InstrumentProvider.NOOP, conf, eventLoopGroup) {
                 public CompletableFuture<CommandWatchTopicListSuccess> newWatchTopicList(
                         BaseCommand command, long requestId) {
                     // Inject 2 seconds delay when sending command New Watch Topics.
@@ -1025,17 +1024,17 @@ public class PatternTopicsConsumerImplTest extends ProducerConsumerBase {
 
         // 6. remove producer 1,3; verify only consumer 2 left
         // seems no direct way to verify auto-unsubscribe, because this patternConsumer also referenced the topic.
-        String tp2p0 = TopicName.get(topicName2).getPartition(0).toString();
-        String tp2p1 = TopicName.get(topicName2).getPartition(1).toString();
-        List<String> topicNames = Lists.newArrayList(tp2p0, tp2p1);
+        List<String> topicNames = Lists.newArrayList(topicName2);
         NamespaceService nss = pulsar.getNamespaceService();
         doReturn(CompletableFuture.completedFuture(topicNames)).when(nss)
                 .getListOfPersistentTopics(NamespaceName.get("my-property/my-ns"));
 
         // 7. call recheckTopics to unsubscribe topic 1,3, verify topics number: 2=6-1-3
         log.debug("recheck topics change");
-        PatternConsumerUpdateQueue taskQueue = WhiteboxImpl.getInternalState(consumer, "updateTaskQueue");
-        taskQueue.appendRecheckOp();
+        PatternMultiTopicsConsumerImpl<byte[]> consumer1 = ((PatternMultiTopicsConsumerImpl<byte[]>) consumer);
+        Timeout recheckPatternTimeout = spy(consumer1.getRecheckPatternTimeout());
+        doReturn(false).when(recheckPatternTimeout).isCancelled();
+        consumer1.run(recheckPatternTimeout);
         Thread.sleep(100);
         assertEquals(((PatternMultiTopicsConsumerImpl<byte[]>) consumer).getPartitions().size(), 2);
         assertEquals(((PatternMultiTopicsConsumerImpl<byte[]>) consumer).getConsumers().size(), 2);
@@ -1116,57 +1115,4 @@ public class PatternTopicsConsumerImplTest extends ProducerConsumerBase {
         assertEquals(pulsar.getBrokerService().getTopicIfExists(baseTopicName + "-1").join(), Optional.empty());
         assertTrue(pulsar.getBrokerService().getTopicIfExists(baseTopicName + "-2").join().isPresent());
     }
-
-    @Test(dataProvider = "partitioned")
-    public void testPatternQuote(boolean partitioned) throws Exception {
-        final NamespaceName namespace = NamespaceName.get("public/default");
-        final String topicName = BrokerTestUtil.newUniqueName("persistent://public/default/tp");
-        final PulsarClientImpl client = (PulsarClientImpl) pulsarClient;
-        final LookupService lookup = client.getLookup();
-        List<String> expectedRes = new ArrayList<>();
-        if (partitioned) {
-            admin.topics().createPartitionedTopic(topicName, 2);
-            expectedRes.add(TopicName.get(topicName).getPartition(0).toString());
-            expectedRes.add(TopicName.get(topicName).getPartition(1).toString());
-            Collections.sort(expectedRes);
-        } else {
-            admin.topics().createNonPartitionedTopic(topicName);
-            expectedRes.add(topicName);
-        }
-
-        // Verify 1: "java.util.regex.Pattern.quote".
-        String pattern1 = java.util.regex.Pattern.quote(topicName);
-        List<String> res1 = lookup.getTopicsUnderNamespace(namespace, CommandGetTopicsOfNamespace.Mode.PERSISTENT,
-                        pattern1, null).join().getNonPartitionedOrPartitionTopics();
-        Collections.sort(res1);
-        assertEquals(res1, expectedRes);
-
-        // Verify 2: "com.google.re2j.Pattern.quote"
-        String pattern2 = com.google.re2j.Pattern.quote(topicName);
-        List<String> res2 = lookup.getTopicsUnderNamespace(namespace, CommandGetTopicsOfNamespace.Mode.PERSISTENT,
-                pattern2, null).join().getNonPartitionedOrPartitionTopics();
-        Collections.sort(res2);
-        assertEquals(res2, expectedRes);
-
-        // Verify 3: "java.util.regex.Pattern.quote" & "^$"
-        String pattern3 = "^" + java.util.regex.Pattern.quote(topicName) + "$";
-        List<String> res3 = lookup.getTopicsUnderNamespace(namespace, CommandGetTopicsOfNamespace.Mode.PERSISTENT,
-                pattern3, null).join().getNonPartitionedOrPartitionTopics();
-        Collections.sort(res3);
-        assertEquals(res3, expectedRes);
-
-        // Verify 4: "com.google.re2j.Pattern.quote" & "^$"
-        String pattern4 = "^" + com.google.re2j.Pattern.quote(topicName) + "$";
-        List<String> res4 = lookup.getTopicsUnderNamespace(namespace, CommandGetTopicsOfNamespace.Mode.PERSISTENT,
-                pattern4, null).join().getNonPartitionedOrPartitionTopics();
-        Collections.sort(res4);
-        assertEquals(res4, expectedRes);
-
-        // cleanup.
-        if (partitioned) {
-            admin.topics().deletePartitionedTopic(topicName, false);
-        } else {
-            admin.topics().delete(topicName, false);
-        }
-    }
 }
