@@ -1880,7 +1880,6 @@ public class NamespacesImpl extends BaseResource implements Namespaces {
     @Override
     public CompletableFuture<Void> clearPropertiesAsync(String namespace) {
         NamespaceName ns = NamespaceName.get(namespace);
-        final CompletableFuture<String> future = new CompletableFuture<>();
         WebTarget path = namespacePath(ns, "properties");
         return asyncDeleteRequest(path);
     }
@@ -1958,4 +1957,40 @@ public class NamespacesImpl extends BaseResource implements Namespaces {
         WebTarget path = namespacePath(ns, "entryFilters");
         return asyncDeleteRequest(path);
     }
+
+    @Override
+    public CompletableFuture<Void> setDispatcherPauseOnAckStatePersistentAsync(String namespace) {
+        NamespaceName ns = NamespaceName.get(namespace);
+        WebTarget path = namespacePath(ns, "dispatcherPauseOnAckStatePersistent");
+        return asyncPostRequest(path, Entity.entity("", MediaType.APPLICATION_JSON));
+    }
+
+    @Override
+    public void setDispatcherPauseOnAckStatePersistent(String namespace) throws PulsarAdminException {
+        sync(() -> setDispatcherPauseOnAckStatePersistentAsync(namespace));
+    }
+
+    @Override
+    public CompletableFuture<Void> removeDispatcherPauseOnAckStatePersistentAsync(String namespace) {
+        NamespaceName ns = NamespaceName.get(namespace);
+        WebTarget path = namespacePath(ns, "dispatcherPauseOnAckStatePersistent");
+        return asyncDeleteRequest(path);
+    }
+
+    @Override
+    public void removeDispatcherPauseOnAckStatePersistent(String namespace) throws PulsarAdminException {
+        sync(() -> removeDispatcherPauseOnAckStatePersistentAsync(namespace));
+    }
+
+    @Override
+    public CompletableFuture<Boolean> getDispatcherPauseOnAckStatePersistentAsync(String namespace) {
+        NamespaceName ns = NamespaceName.get(namespace);
+        WebTarget path = namespacePath(ns, "dispatcherPauseOnAckStatePersistent");
+        return asyncGetRequest(path, new FutureCallback<Boolean>(){});
+    }
+
+    @Override
+    public boolean getDispatcherPauseOnAckStatePersistent(String namespace) throws PulsarAdminException {
+        return sync(() -> getDispatcherPauseOnAckStatePersistentAsync(namespace));
+    }
 }
