@@ -29,13 +29,9 @@ import static org.mockito.Mockito.when;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertNull;
 import static org.testng.Assert.assertTrue;
-
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.io.OutputStream;
-import java.io.PrintStream;
-import java.util.Arrays;
-import java.util.List;
+import java.io.PrintWriter;
+import java.io.StringWriter;
+import lombok.Cleanup;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.pulsar.admin.cli.CmdFunctions.CreateFunction;
 import org.apache.pulsar.admin.cli.CmdFunctions.DeleteFunction;
@@ -55,6 +51,7 @@ import org.apache.pulsar.functions.api.Function;
 import org.apache.pulsar.functions.api.utils.IdentityFunction;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
+import picocli.CommandLine;
 
 /**
  * Unit test of {@link CmdFunctions}.
@@ -168,7 +165,8 @@ public class CmdFunctionsTest {
             "--className", DummyFunction.class.getName(),
             "--dead-letter-topic", "test-dead-letter-topic",
             "--custom-runtime-options", "custom-runtime-options",
-            "--user-config", "{\"key\": [\"value1\", \"value2\"]}"
+            "--user-config", "{\"key\": [\"value1\", \"value2\"]}",
+            "--runtime-flags", "--add-opens java.base/java.lang=ALL-UNNAMED"
         });
 
         CreateFunction creater = cmd.getCreater();
@@ -178,6 +176,7 @@ public class CmdFunctionsTest {
         assertEquals(Boolean.FALSE, creater.getAutoAck());
         assertEquals("test-dead-letter-topic", creater.getDeadLetterTopic());
         assertEquals("custom-runtime-options", creater.getCustomRuntimeOptions());
+        assertEquals("--add-opens java.base/java.lang=ALL-UNNAMED", creater.getRuntimeFlags());
 
         verify(functions, times(1)).createFunction(any(FunctionConfig.class), anyString());
 
@@ -542,11 +541,12 @@ public class CmdFunctionsTest {
 
 
     @Test
-    public void testCreateWithoutOutputTopic() {
-
-        ConsoleOutputCapturer consoleOutputCapturer = new ConsoleOutputCapturer();
-        consoleOutputCapturer.start();
-
+    public void testCreateWithoutOutputTopic() throws Exception {
+        @Cleanup
+        StringWriter stringWriter = new StringWriter();
+        @Cleanup
+        PrintWriter printWriter = new PrintWriter(stringWriter);
+        cmd.getCommander().setOut(printWriter);
         cmd.run(new String[] {
                 "create",
                 "--inputs", INPUT_TOPIC_NAME,
@@ -557,9 +557,8 @@ public class CmdFunctionsTest {
         });
 
         CreateFunction creater = cmd.getCreater();
-        consoleOutputCapturer.stop();
         assertNull(creater.getFunctionConfig().getOutput());
-        assertTrue(consoleOutputCapturer.getStdout().contains("Created successfully"));
+        assertTrue(stringWriter.toString().contains("Created successfully"));
     }
 
     @Test
@@ -632,19 +631,6 @@ public class CmdFunctionsTest {
         verify(functions, times(1)).getFunctions(eq(TENANT), eq(NAMESPACE));
     }
 
-    @Test
-    public void testListFunctionsWithDefaultValue() throws Exception {
-        cmd.run(new String[] {
-                "list",
-        });
-
-        ListFunctions lister = cmd.getLister();
-        assertEquals("public", lister.getTenant());
-        assertEquals("default", lister.getNamespace());
-
-        verify(functions, times(1)).getFunctions(eq("public"), eq("default"));
-    }
-
     @Test
     public void testStateGetter() throws Exception {
         String key = TEST_NAME + "-key";
@@ -668,17 +654,19 @@ public class CmdFunctionsTest {
 
     @Test
     public void testStateGetterWithoutKey() throws Exception {
-        ConsoleOutputCapturer consoleOutputCapturer = new ConsoleOutputCapturer();
-        consoleOutputCapturer.start();
-        cmd.run(new String[] {
+        CommandLine commander = cmd.getCommander();
+        @Cleanup
+        StringWriter stringWriter = new StringWriter();
+        @Cleanup
+        PrintWriter printWriter = new PrintWriter(stringWriter);
+        commander.setErr(printWriter);
+        cmd.run(new String[]{
                 "querystate",
                 "--tenant", TENANT,
                 "--namespace", NAMESPACE,
                 "--name", FN_NAME,
         });
-        consoleOutputCapturer.stop();
-        String output = consoleOutputCapturer.getStderr();
-        assertTrue(output.replace("\n", "").contains("State key needs to be specified"));
+        assertTrue(stringWriter.toString().startsWith(("State key needs to be specified")));
         StateGetter stateGetter = cmd.getStateGetter();
         assertEquals(TENANT, stateGetter.getTenant());
         assertEquals(NAMESPACE, stateGetter.getNamespace());
@@ -909,79 +897,4 @@ public class CmdFunctionsTest {
         verify(functions, times(1))
                 .downloadFunction(JAR_NAME, TENANT, NAMESPACE, FN_NAME, true);
     }
-
-
-    public static class ConsoleOutputCapturer {
-        private ByteArrayOutputStream stdout;
-        private ByteArrayOutputStream stderr;
-        private PrintStream previous;
-        private boolean capturing;
-
-        public void start() {
-            if (capturing) {
-                return;
-            }
-
-            capturing = true;
-            previous = System.out;
-            stdout = new ByteArrayOutputStream();
-            stderr = new ByteArrayOutputStream();
-
-            OutputStream outputStreamCombinerstdout =
-                    new OutputStreamCombiner(Arrays.asList(previous, stdout));
-            PrintStream stdoutStream = new PrintStream(outputStreamCombinerstdout);
-
-            OutputStream outputStreamCombinerStderr =
-                    new OutputStreamCombiner(Arrays.asList(previous, stderr));
-            PrintStream stderrStream = new PrintStream(outputStreamCombinerStderr);
-
-            System.setOut(stdoutStream);
-            System.setErr(stderrStream);
-        }
-
-        public void stop() {
-            if (!capturing) {
-                return;
-            }
-
-            System.setOut(previous);
-
-            previous = null;
-            capturing = false;
-        }
-
-        public String getStdout() {
-            return stdout.toString();
-        }
-
-        public String getStderr() {
-            return stderr.toString();
-        }
-
-        private static class OutputStreamCombiner extends OutputStream {
-            private List<OutputStream> outputStreams;
-
-            public OutputStreamCombiner(List<OutputStream> outputStreams) {
-                this.outputStreams = outputStreams;
-            }
-
-            public void write(int b) throws IOException {
-                for (OutputStream os : outputStreams) {
-                    os.write(b);
-                }
-            }
-
-            public void flush() throws IOException {
-                for (OutputStream os : outputStreams) {
-                    os.flush();
-                }
-            }
-
-            public void close() throws IOException {
-                for (OutputStream os : outputStreams) {
-                    os.close();
-                }
-            }
-        }
-    }
 }
