@@ -20,8 +20,11 @@ package org.apache.pulsar.client.impl;
 
 import static java.lang.String.format;
 import io.netty.buffer.ByteBuf;
+import io.opentelemetry.api.common.Attributes;
 import java.net.InetSocketAddress;
 import java.net.URI;
+import java.util.ArrayList;
+import java.util.List;
 import java.util.Optional;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ConcurrentHashMap;
@@ -32,6 +35,7 @@ import java.util.concurrent.atomic.AtomicLong;
 import org.apache.commons.lang3.mutable.MutableObject;
 import org.apache.pulsar.client.api.PulsarClientException;
 import org.apache.pulsar.client.api.SchemaSerializationException;
+import org.apache.pulsar.client.impl.metrics.LatencyHistogram;
 import org.apache.pulsar.common.api.proto.CommandGetTopicsOfNamespace.Mode;
 import org.apache.pulsar.common.api.proto.CommandLookupTopicResponse;
 import org.apache.pulsar.common.api.proto.CommandLookupTopicResponse.LookupType;
@@ -63,6 +67,11 @@ public class BinaryProtoLookupService implements LookupService {
     private final ConcurrentHashMap<TopicName, CompletableFuture<PartitionedTopicMetadata>>
             partitionedMetadataInProgress = new ConcurrentHashMap<>();
 
+    private final LatencyHistogram histoGetBroker;
+    private final LatencyHistogram histoGetTopicMetadata;
+    private final LatencyHistogram histoGetSchema;
+    private final LatencyHistogram histoListTopics;
+
     public BinaryProtoLookupService(PulsarClientImpl client,
                                     String serviceUrl,
                                     boolean useTls,
@@ -84,6 +93,15 @@ public class BinaryProtoLookupService implements LookupService {
         this.serviceNameResolver = new PulsarServiceNameResolver();
         this.listenerName = listenerName;
         updateServiceUrl(serviceUrl);
+
+        LatencyHistogram histo = client.instrumentProvider().newLatencyHistogram("pulsar.client.lookup.duration",
+                "Duration of lookup operations", null,
+                Attributes.builder().put("pulsar.lookup.transport-type", "binary").build());
+        histoGetBroker = histo.withAttributes(Attributes.builder().put("pulsar.lookup.type", "topic").build());
+        histoGetTopicMetadata =
+                histo.withAttributes(Attributes.builder().put("pulsar.lookup.type", "metadata").build());
+        histoGetSchema = histo.withAttributes(Attributes.builder().put("pulsar.lookup.type", "schema").build());
+        histoListTopics = histo.withAttributes(Attributes.builder().put("pulsar.lookup.type", "list-topics").build());
     }
 
     @Override
@@ -99,12 +117,20 @@ public class BinaryProtoLookupService implements LookupService {
      * @return broker-socket-address that serves given topic
      */
     public CompletableFuture<LookupTopicResult> getBroker(TopicName topicName) {
+        long startTime = System.nanoTime();
         final MutableObject<CompletableFuture> newFutureCreated = new MutableObject<>();
         try {
             return lookupInProgress.computeIfAbsent(topicName, tpName -> {
                 CompletableFuture<LookupTopicResult> newFuture =
                         findBroker(serviceNameResolver.resolveHost(), false, topicName, 0);
                 newFutureCreated.setValue(newFuture);
+
+                newFuture.thenRun(() -> {
+                    histoGetBroker.recordSuccess(System.nanoTime() - startTime);
+                }).exceptionally(x -> {
+                    histoGetBroker.recordFailure(System.nanoTime() - startTime);
+                    return null;
+                });
                 return newFuture;
             });
         } finally {
@@ -224,6 +250,7 @@ public class BinaryProtoLookupService implements LookupService {
     private CompletableFuture<PartitionedTopicMetadata> getPartitionedTopicMetadata(InetSocketAddress socketAddress,
             TopicName topicName) {
 
+        long startTime = System.nanoTime();
         CompletableFuture<PartitionedTopicMetadata> partitionFuture = new CompletableFuture<>();
 
         client.getCnxPool().getConnection(socketAddress).thenAccept(clientCnx -> {
@@ -231,11 +258,13 @@ public class BinaryProtoLookupService implements LookupService {
             ByteBuf request = Commands.newPartitionMetadataRequest(topicName.toString(), requestId);
             clientCnx.newLookup(request, requestId).whenComplete((r, t) -> {
                 if (t != null) {
+                    histoGetTopicMetadata.recordFailure(System.nanoTime() - startTime);
                     log.warn("[{}] failed to get Partitioned metadata : {}", topicName,
                         t.getMessage(), t);
                     partitionFuture.completeExceptionally(t);
                 } else {
                     try {
+                        histoGetTopicMetadata.recordSuccess(System.nanoTime() - startTime);
                         partitionFuture.complete(new PartitionedTopicMetadata(r.partitions));
                     } catch (Exception e) {
                         partitionFuture.completeExceptionally(new PulsarClientException.LookupException(
@@ -263,6 +292,7 @@ public class BinaryProtoLookupService implements LookupService {
 
     @Override
     public CompletableFuture<Optional<SchemaInfo>> getSchema(TopicName topicName, byte[] version) {
+        long startTime = System.nanoTime();
         CompletableFuture<Optional<SchemaInfo>> schemaFuture = new CompletableFuture<>();
         if (version != null && version.length == 0) {
             schemaFuture.completeExceptionally(new SchemaSerializationException("Empty schema version"));
@@ -275,10 +305,12 @@ public class BinaryProtoLookupService implements LookupService {
                 Optional.ofNullable(BytesSchemaVersion.of(version)));
             clientCnx.sendGetSchema(request, requestId).whenComplete((r, t) -> {
                 if (t != null) {
+                    histoGetSchema.recordFailure(System.nanoTime() - startTime);
                     log.warn("[{}] failed to get schema : {}", topicName,
                         t.getMessage(), t);
                     schemaFuture.completeExceptionally(t);
                 } else {
+                    histoGetSchema.recordSuccess(System.nanoTime() - startTime);
                     schemaFuture.complete(r);
                 }
                 client.getCnxPool().releaseConnection(clientCnx);
@@ -326,6 +358,8 @@ public class BinaryProtoLookupService implements LookupService {
                                          Mode mode,
                                          String topicsPattern,
                                          String topicsHash) {
+        long startTime = System.nanoTime();
+
         client.getCnxPool().getConnection(socketAddress).thenAccept(clientCnx -> {
             long requestId = client.newRequestId();
             ByteBuf request = Commands.newGetTopicsOfNamespaceRequest(
@@ -333,13 +367,25 @@ public class BinaryProtoLookupService implements LookupService {
 
             clientCnx.newGetTopicsOfNamespace(request, requestId).whenComplete((r, t) -> {
                 if (t != null) {
+                    histoListTopics.recordFailure(System.nanoTime() - startTime);
                     getTopicsResultFuture.completeExceptionally(t);
                 } else {
+                    histoListTopics.recordSuccess(System.nanoTime() - startTime);
                     if (log.isDebugEnabled()) {
                         log.debug("[namespace: {}] Success get topics list in request: {}",
                                 namespace, requestId);
                     }
-                    getTopicsResultFuture.complete(r);
+                    // do not keep partition part of topic name
+                    List<String> result = new ArrayList<>();
+                    r.getTopics().forEach(topic -> {
+                        String filtered = TopicName.get(topic).getPartitionedTopicName();
+                        if (!result.contains(filtered)) {
+                            result.add(filtered);
+                        }
+                    });
+
+                    getTopicsResultFuture.complete(new GetTopicsResult(result, r.getTopicsHash(),
+                            r.isFiltered(), r.isChanged()));
                 }
                 client.getCnxPool().releaseConnection(clientCnx);
             });
