@@ -32,7 +32,6 @@ import java.time.Clock;
 import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
@@ -71,6 +70,7 @@ import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
 import org.apache.pulsar.client.impl.conf.ConsumerConfigurationData;
 import org.apache.pulsar.client.impl.conf.ProducerConfigurationData;
 import org.apache.pulsar.client.impl.conf.ReaderConfigurationData;
+import org.apache.pulsar.client.impl.metrics.InstrumentProvider;
 import org.apache.pulsar.client.impl.schema.AutoConsumeSchema;
 import org.apache.pulsar.client.impl.schema.AutoProduceBytesSchema;
 import org.apache.pulsar.client.impl.schema.generic.GenericAvroSchema;
@@ -152,6 +152,8 @@ public class PulsarClientImpl implements PulsarClient {
 
     private final Clock clientClock;
 
+    private final InstrumentProvider instrumentProvider;
+
     @Getter
     private TransactionCoordinatorClientImpl tcClient;
 
@@ -179,6 +181,7 @@ public class PulsarClientImpl implements PulsarClient {
                              Timer timer, ExecutorProvider externalExecutorProvider,
                              ExecutorProvider internalExecutorProvider,
                              ScheduledExecutorProvider scheduledExecutorProvider) throws PulsarClientException {
+
         EventLoopGroup eventLoopGroupReference = null;
         ConnectionPool connectionPoolReference = null;
         try {
@@ -196,10 +199,12 @@ public class PulsarClientImpl implements PulsarClient {
                 throw new PulsarClientException.InvalidConfigurationException("Invalid client configuration");
             }
             this.conf = conf;
+            this.instrumentProvider = new InstrumentProvider(conf.getOpenTelemetry());
             clientClock = conf.getClock();
             conf.getAuthentication().start();
             connectionPoolReference =
-                    connectionPool != null ? connectionPool : new ConnectionPool(conf, this.eventLoopGroup);
+                    connectionPool != null ? connectionPool :
+                            new ConnectionPool(instrumentProvider, conf, this.eventLoopGroup);
             this.cnxPool = connectionPoolReference;
             this.externalExecutorProvider = externalExecutorProvider != null ? externalExecutorProvider :
                     new ExecutorProvider(conf.getNumListenerThreads(), "pulsar-external-listener");
@@ -208,7 +213,7 @@ public class PulsarClientImpl implements PulsarClient {
             this.scheduledExecutorProvider = scheduledExecutorProvider != null ? scheduledExecutorProvider :
                     new ScheduledExecutorProvider(conf.getNumIoThreads(), "pulsar-client-scheduled");
             if (conf.getServiceUrl().startsWith("http")) {
-                lookup = new HttpLookupService(conf, this.eventLoopGroup);
+                lookup = new HttpLookupService(instrumentProvider, conf, this.eventLoopGroup);
             } else {
                 lookup = new BinaryProtoLookupService(this, conf.getServiceUrl(), conf.getListenerName(),
                         conf.isUseTls(), this.scheduledExecutorProvider.getExecutor());
@@ -577,13 +582,12 @@ public class PulsarClientImpl implements PulsarClient {
         lookup.getTopicsUnderNamespace(namespaceName, subscriptionMode, regex, null)
             .thenAccept(getTopicsResult -> {
                 if (log.isDebugEnabled()) {
-                    log.debug("Pattern consumer [{}] get topics under namespace {}, topics.size: {},"
-                                    + " topicsHash: {}, changed: {}, filtered: {}", conf.getSubscriptionName(),
+                    log.debug("Get topics under namespace {}, topics.size: {},"
+                                    + " topicsHash: {}, changed: {}, filtered: {}",
                             namespaceName, getTopicsResult.getTopics().size(), getTopicsResult.getTopicsHash(),
                             getTopicsResult.isChanged(), getTopicsResult.isFiltered());
                     getTopicsResult.getTopics().forEach(topicName ->
-                        log.debug("Pattern consumer [{}] get topics under namespace {}, topic: {}",
-                                conf.getSubscriptionName(), namespaceName, topicName));
+                        log.debug("Get topics under namespace {}, topic: {}", namespaceName, topicName));
                 }
 
                 List<String> topicsList = getTopicsResult.getTopics();
@@ -591,14 +595,6 @@ public class PulsarClientImpl implements PulsarClient {
                    topicsList = TopicList.filterTopics(getTopicsResult.getTopics(), conf.getTopicsPattern());
                 }
                 conf.getTopicNames().addAll(topicsList);
-
-                if (log.isDebugEnabled()) {
-                    log.debug("Pattern consumer [{}] initialize topics. {}", conf.getSubscriptionName(),
-                            getTopicsResult.getNonPartitionedOrPartitionTopics());
-                }
-
-                // Pattern consumer has his unique check mechanism, so do not need the feature "autoUpdatePartitions".
-                conf.setAutoUpdatePartitions(false);
                 ConsumerBase<T> consumer = new PatternMultiTopicsConsumerImpl<>(conf.getTopicsPattern(),
                         getTopicsResult.getTopicsHash(),
                         PulsarClientImpl.this,
@@ -746,21 +742,6 @@ public class PulsarClientImpl implements PulsarClient {
         }
     }
 
-    private void closeUrlLookupMap() {
-        Map<String, LookupService> closedUrlLookupServices = new HashMap(urlLookupMap.size());
-        urlLookupMap.entrySet().forEach(e -> {
-            try {
-                e.getValue().close();
-            } catch (Exception ex) {
-                log.error("Error closing lookup service {}", e.getKey(), ex);
-            }
-            closedUrlLookupServices.put(e.getKey(), e.getValue());
-        });
-        closedUrlLookupServices.entrySet().forEach(e -> {
-            urlLookupMap.remove(e.getKey(), e.getValue());
-        });
-    }
-
     @Override
     public CompletableFuture<Void> closeAsync() {
         log.info("Client closing. URL: {}", lookup.getServiceUrl());
@@ -771,8 +752,6 @@ public class PulsarClientImpl implements PulsarClient {
         final CompletableFuture<Void> closeFuture = new CompletableFuture<>();
         List<CompletableFuture<Void>> futures = new ArrayList<>();
 
-        closeUrlLookupMap();
-
         producers.forEach(p -> futures.add(p.closeAsync().handle((__, t) -> {
             if (t != null) {
                 log.error("Error closing producer {}", p, t);
@@ -1001,10 +980,6 @@ public class PulsarClientImpl implements PulsarClient {
 
     public LookupService getLookup(String serviceUrl) {
         return urlLookupMap.computeIfAbsent(serviceUrl, url -> {
-            if (isClosed()) {
-                throw new IllegalStateException("Pulsar client has been closed, can not build LookupService when"
-                        + " calling get lookup with an url");
-            }
             try {
                 return createLookup(serviceUrl);
             } catch (PulsarClientException e) {
@@ -1086,7 +1061,7 @@ public class PulsarClientImpl implements PulsarClient {
 
     public LookupService createLookup(String url) throws PulsarClientException {
         if (url.startsWith("http")) {
-            return new HttpLookupService(conf, eventLoopGroup);
+            return new HttpLookupService(instrumentProvider, conf, eventLoopGroup);
         } else {
             return new BinaryProtoLookupService(this, url, conf.getListenerName(), conf.isUseTls(),
                     externalExecutorProvider.getExecutor());
@@ -1264,6 +1239,11 @@ public class PulsarClientImpl implements PulsarClient {
         return scheduledExecutorProvider;
     }
 
+    InstrumentProvider instrumentProvider() {
+        return instrumentProvider;
+    }
+
+
     //
     // Transaction related API
     //
