@@ -18,28 +18,29 @@
  */
 package org.apache.pulsar.io.rabbitmq;
 
-import org.apache.qpid.server.Broker;
-import org.apache.qpid.server.BrokerOptions;
-
 import java.io.File;
 import java.io.FileOutputStream;
 import java.nio.file.Files;
 import java.nio.file.Path;
+import java.util.HashMap;
+import java.util.Map;
+import org.apache.qpid.server.SystemLauncher;
+import org.apache.qpid.server.model.SystemConfig;
 
 public class RabbitMQBrokerManager {
 
-    private final Broker broker = new Broker();
+    private final SystemLauncher systemLauncher = new SystemLauncher();
 
     public void startBroker(String port) throws Exception {
-        BrokerOptions brokerOptions = getBrokerOptions(port);
-        broker.startup(brokerOptions);
+        Map<String, Object> brokerOptions = getBrokerOptions(port);
+        systemLauncher.startup(brokerOptions);
     }
 
     public void stopBroker() {
-        broker.shutdown();
+        systemLauncher.shutdown();
     }
 
-    BrokerOptions getBrokerOptions(String port) throws Exception {
+    Map<String, Object> getBrokerOptions(String port) throws Exception {
         Path tmpFolder = Files.createTempDirectory("qpidWork");
         Path homeFolder = Files.createTempDirectory("qpidHome");
         File etc = new File(homeFolder.toFile(), "etc");
@@ -48,15 +49,17 @@ public class RabbitMQBrokerManager {
         fos.write("guest:guest\n".getBytes());
         fos.close();
 
-        BrokerOptions brokerOptions = new BrokerOptions();
-
-        brokerOptions.setConfigProperty("qpid.work_dir", tmpFolder.toAbsolutePath().toString());
-        brokerOptions.setConfigProperty("qpid.amqp_port", port);
-        brokerOptions.setConfigProperty("qpid.home_dir", homeFolder.toAbsolutePath().toString());
+        Map<String, Object> config = new HashMap<>();
+        config.put("qpid.work_dir", tmpFolder.toAbsolutePath().toString());
+        config.put("qpid.amqp_port", port);
+        config.put("qpid.home_dir", homeFolder.toAbsolutePath().toString());
         String configPath = getFile("qpid.json").getAbsolutePath();
-        brokerOptions.setInitialConfigurationLocation(configPath);
 
-        return brokerOptions;
+        Map<String, Object> context = new HashMap<>();
+        context.put(SystemConfig.INITIAL_CONFIGURATION_LOCATION, configPath);
+        context.put(SystemConfig.TYPE, "Memory");
+        context.put(SystemConfig.CONTEXT, config);
+        return context;
     }
 
     private File getFile(String name) {
