@@ -112,8 +112,7 @@ public class RocksdbMetadataStore extends AbstractMetadataStore {
         // Create a new store instance
         store = new RocksdbMetadataStore(metadataStoreUri, conf);
         // update synchronizer and register sync listener
-        store.synchronizer = conf.getSynchronizer();
-        store.registerSyncListener(Optional.ofNullable(store.synchronizer));
+        store.updateMetadataEventSynchronizer(conf.getSynchronizer());
         instancesCache.put(metadataStoreUri, store);
         return store;
     }
@@ -376,9 +375,6 @@ public class RocksdbMetadataStore extends AbstractMetadataStore {
         }
         try {
             dbStateLock.readLock().lock();
-            if (isClosed()) {
-                return alreadyClosedFailedFuture();
-            }
             byte[] value = db.get(optionCache, toBytes(path));
             if (value == null) {
                 return CompletableFuture.completedFuture(Optional.empty());
@@ -411,9 +407,6 @@ public class RocksdbMetadataStore extends AbstractMetadataStore {
         }
         try {
             dbStateLock.readLock().lock();
-            if (isClosed()) {
-                return alreadyClosedFailedFuture();
-            }
             try (RocksIterator iterator = db.newIterator(optionDontCache)) {
                 Set<String> result = new HashSet<>();
                 String firstKey = path.equals("/") ? path : path + "/";
@@ -456,9 +449,6 @@ public class RocksdbMetadataStore extends AbstractMetadataStore {
         }
         try {
             dbStateLock.readLock().lock();
-            if (isClosed()) {
-                return alreadyClosedFailedFuture();
-            }
             byte[] value = db.get(optionDontCache, toBytes(path));
             if (log.isDebugEnabled()) {
                 if (value != null) {
@@ -481,9 +471,6 @@ public class RocksdbMetadataStore extends AbstractMetadataStore {
         }
         try {
             dbStateLock.readLock().lock();
-            if (isClosed()) {
-                return alreadyClosedFailedFuture();
-            }
             try (Transaction transaction = db.beginTransaction(writeOptions)) {
                 byte[] pathBytes = toBytes(path);
                 byte[] oldValueData = transaction.getForUpdate(optionDontCache, pathBytes, true);
@@ -520,9 +507,6 @@ public class RocksdbMetadataStore extends AbstractMetadataStore {
         }
         try {
             dbStateLock.readLock().lock();
-            if (isClosed()) {
-                return alreadyClosedFailedFuture();
-            }
             try (Transaction transaction = db.beginTransaction(writeOptions)) {
                 byte[] pathBytes = toBytes(path);
                 byte[] oldValueData = transaction.getForUpdate(optionDontCache, pathBytes, true);
@@ -587,6 +571,12 @@ public class RocksdbMetadataStore extends AbstractMetadataStore {
     public Optional<MetadataEventSynchronizer> getMetadataEventSynchronizer() {
         return Optional.ofNullable(synchronizer);
     }
+
+    @Override
+    public void updateMetadataEventSynchronizer(MetadataEventSynchronizer synchronizer) {
+        this.synchronizer = synchronizer;
+        registerSyncListener(Optional.ofNullable(synchronizer));
+    }
 }
 
 class RocksdbMetadataStoreProvider implements MetadataStoreProvider {
